import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Marketing Manager related titles

marketing_manager_variants = [
    # Standard Titles & Abbreviations
    r"(?i)\bMarketing\s?Manager\b",
    r"(?i)\bMarketing\s?Mng\b",
    r"(?i)\bMarketing\s?Mgr\b",
    r"(?i)\bMkt\s?Manager\b",
    r"(?i)\bMktg\s?Manager\b",
    r"(?i)\bMarketing\b",
    r"(?i)\bBrand Manager\b",
    r"(?i)\bCommercial Director\b",
    r"(?i)\bDesigner\b",
    r"(?i)\bCommercial Manager\b",
    r"(?i)\bChannel Manager\b",
    r"(?i)\bCosmetic PhysicianPodcast Host\b",
    r"(?i)\bEditorial Coordinator\b",
    r"(?i)\bP R  Medicina Estetica\b",
    r"(?i)\bP R\b",
    r"(?i)\bPR\b",
    r"(?i)\bPr & Social Media Coordinator\b",
    r"(?i)\bPR Specialist\b",
    r"(?i)\bSocial Media Pr Assistant\b",
    r"(?i)Social Media",
    r"(?i)\bHead Of Mr\b",
    r"(?i)\bPortfolio Sr  Manager\b",
    r"(?i)\bHead Of Communication\b",
    r"(?i)\bCommunication Manager\b",
    r"(?i)\bBrand Strategist\b",
    r"(?i)\bSeo Errors\b",
    r"(?i)\bBusiness Development Health Care\b",
    r"(?i)\bDigital Manager\b",
    r"(?i)\bAnalista De Mercadeo\b",
    r"(?i)\bPrint Strategist\b",
    r"(?i)\bAds\b",
    r"(?i)Business Development Manager",
    r"(?i)Content Strategist",
    r"(?i)Publicitaria",
    r"(?i)Business Development",
    r"(?i)\bPublicist\b",
    r"(?i)\bSeo\b",
    r"(?i)\bVideo Adds\b",
    r"(?i)\bMarket Mgr\b",
    r"(?i)\bMrktng Dir\b",
    r"(?i)\bStrategist\b",
    r"(?i)\bCorporate Communication\b",
    r"(?i)\bMedical Communication\b",
    r"(?i)\bMkt\b",
    r"(?i)\bLatest Innovations In Healthcare News Website\b",
    r"(?i)\bBdm\b",
    r"(?i)\bDev Web & Communication\b",
    r"(?i)\bBusiness Excellence Lead\b",
    r"(?i)\bVideos Add\b",
    r"(?i)\bEditorial\b",
    r"(?i)\bOnline\b",
    r"(?i)Facebook",
    r"(?i)Instagram",
    r"(?i)Digital Marketing",
    r"(?i)Marketing",
    r"(?i)Copywriter",
    r"(?i)\bCommunication\b",
    r"(?i)\bBusiness Developement\b",
    r"(?i)\bMktg Dir Botox\b",
    r"(?i)\bChargee De Communication\b",
    r"(?i)\bCommunication Agency\b",
    r"(?i)\bBody Contouring Product Marketing Manager\b",
    r"(?i)\bBusiness Growth\b",
    r"(?i)\bAssociate Media Director\b",
    r"(?i)\bBusiness Associate\b",
    r"(?i)\bMedia Supervisor\b",
    r"(?i)\bHvac Supervisor Or Telecom\b",
    r"(?i)\bSenior Media Supervisor\b",
    r"(?i)\bPrint Supervisor\b",
    r"(?i)\bMarketing & Communications Coordinator\b",
    r"(?i)\bSocial Media Coordinator\b",
    r"(?i)\bMedia Coordinator\b",
    r"(?i)\bMedia Planner\b",
    r"(?i)\bMedia Assistant\b",
    r"(?i)\bCommunications\b",
    r"(?i)\bVidep Editor\b",

    # Misspellings & Typographical Errors
    r"(?i)\bMarkting\s?Manager\b",
    r"(?i)\bMarketting\s?Manager\b",
    r"(?i)\bMarketing\s?Managr\b",
    r"(?i)\bMarkting\s?Managr\b",
    r"(?i)\bMarkeing\s?Manager\b",
    r"(?i)\bMarketing\s?Maneger\b",
    r"(?i)\bMarketing\s?Manger\b",
    r"(?i)\bMarket\s?Manager\b",

    # Case Variations
    r"(?i)\bmarketing manager\b",
    r"(?i)\bMarketing manager\b",
    r"(?i)\bmarketing Manager\b",
    r"(?i)\bMARKETING MANAGER\b",
    r"(?i)\bMarkEting ManageR\b",

    # Spanish Variants
    r"(?i)\bGerente\s?de\s?Marketing\b",
    r"(?i)\bGerente\s?de\s?Mercadeo\b",
    r"(?i)\bGerente\s?de\s?Publicidad\b",
    r"(?i)\bDirector\s?de\s?Marketing\b",
    r"(?i)\bDirector\s?de\s?Mercadotecnia\b",
    r"(?i)\bGerente\s?de\s?Comercialización\b",
    r"(?i)\bJefe\s?de\s?Marketing\b",
    r"(?i)\bJefe\s?de\s?Publicidad\b",
    r"(?i)\bGerente\s?de\s?Estrategia\s?de\s?Marketing\b",

    # Other Possible Variations
    r"(?i)\bMarketing\s?Head\b",
    r"(?i)\bMarketing\s?Lead\b",
    r"(?i)\bChief\s?Marketing\s?Officer\b",
    r"(?i)\bCMO\b",
    r"(?i)\bHead\s?of\s?Marketing\b",
    r"(?i)\bDigital\s?Marketing\s?Manager\b",
    r"(?i)\bBrand\s?Marketing\s?Manager\b",
    r"(?i)\bAdvertising\s?Manager\b",
    r"(?i)\bMarketing\s?and\s?Communications\s?Manager\b",
    r"(?i)\bStrategic\s?Marketing\s?Manager\b",
    r"(?i)\bProduct\s?Marketing\s?Manager\b",
    r"(?i)\bCorporate\s?Marketing\s?Manager\b",
    r"(?i)\bGrowth\s?Marketing\s?Manager\b",
    r"(?i)\bPerformance\s?Marketing\s?Manager\b",
    r"(?i)\bContent\s?Marketing\s?Manager\b",
    r"(?i)\bBrand Management\b",
    r"(?i)\bPracticeMarketing Manager\b",
    r"(?i)\bPractice ManagerMarketing\b",
    r"(?i)\bBusiness Development Director\b",
    r"(?i)\bBd\b",
    r"(?i)\bBusiness Developer\b",
    r"(?i)\bDirector Of Business Development\b",
    r"(?i)\bDesign\b",
    r"(?i)\bMktg\b",
    r"(?i)Marketer",
    r"(?i)Marketing",
    r"(?i)\bArt\b",
    r"(?i)\bPublisher\b",
    r"(?i)\bDeputy Editor\b",
    r"(?i)\bMarket Development\b",
    r"(?i)\bCommunication Evenementielle\b",
    r"(?i)\bPublication Planning\b",
    r"(?i)\bPr\b",
    r"(?i)\bBrand Manager\b",
    r"(?i)\bBusiness Develoment\b",
    r"(?i)\bMaketing Manager\b",
    r"(?i)\bMarekting Director\b",
    r"(?i)\bMrketing Director\b",
    r"(?i)\bAesthetic Marketplace Manager\b",
    r"(?i)\bCRM Manager\b",
]

# Exact matches that should be updated
marketing_manager_exact_matches = {
    "Marketing Manager",
    "Marketing Mgr",
    "Mkt Manager",
    "Mktg Manager",
    "Markting Manager",
    "Marketting Manager",
    "Marketing Managr",
    "Marketing Mngr",
    "Marketing Maneger",
    "Marketing Manger",
    "Market Manager",
    "Gerente de Marketing",
    "Gerente de Mercadeo",
    "Gerente de Publicidad",
    "Director de Marketing",
    "Director de Mercadotecnia",
    "Gerente de Comercialización",
    "Jefe de Marketing",
    "Jefe de Publicidad",
    "Gerente de Estrategia de Marketing",
    "Marketing Head",
    "Marketing Lead",
    "Chief Marketing Officer",
    "CMO",
    "Head of Marketing",
    "Digital Marketing Manager",
    "Brand Marketing Manager",
    "Advertising Manager",
    "Marketing and Communications Manager",
    "Strategic Marketing Manager",
    "Product Marketing Manager",
    "Corporate Marketing Manager",
    "Growth Marketing Manager",
    "Performance Marketing Manager",
    "Content Marketing Manager",
    "Marketing",
    "Markting",
    "Maketing",
    "Marekting",
    "Marrketing",
    "Markeitng",
    "Maketting",
    "Business Development Manager",
    "Marketing Director",
    "Dev",
    "dev",
    "Business Development",
    "PracticeMarketing Manager",
    "Practice ManagerMarketing",
    "Business Development Director",
    "Bd",
    "Director Of Business Development",
    'Design',
    'Graphiste',
    'Brand Specialist',
    'Facial Aesthetic Publications',
    'Publication Manager',
    'Topic Lead Websessions',
    'Creative Director',
    'Director Of Biz Dev',
    'Advertising Director',
    'Business Stretagy Executive',
    'Desiger',
    'Advertising',
    'Hd Of Bus Dvlpmnt & CommL Ops',
    'Brand Developer',
    'Dev Director',
    'Director of Development',
    'Client Relations',
    'Platform Manager',
    'Director of Business Strategies',
    'Director of Client Relations',
    'Global PRE',
    'Global PRE Director',
    'Loyalty Director',
    'V P Patient Acquisition',
    'Global Development Manager',
    'Regional Director Of Growth & Development',
    'A V',
    'AV',
    'Animator',
    'Creative Director Alle',
    'Creative Partner',
    'Creative director',
    'Digital Content Manager',
    'Dir Global Commerical Development',
    'Display Works',
    'EltaMD Brand Director',
}

# Define patterns (these should NOT be changed)
marketing_manager_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Marketing Manager
mask_marketing_manager = df['speciality'].str.contains('|'.join(marketing_manager_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(marketing_manager_exact_matches)
mask_marketing_manager_exclusions = df['speciality'].isin(marketing_manager_exclusions)

# Final mask: Select Marketing Manager
mask_marketing_manager_final = mask_marketing_manager & ~mask_marketing_manager_exclusions

# Store the original values that will be replaced
original_marketing_manager_values = df.loc[mask_marketing_manager_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_marketing_manager_final, 'speciality'] = 'Marketing Manager'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Marketing Manager", 'green'))
print(df.loc[mask_marketing_manager_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_marketing_manager_values = df.loc[mask_marketing_manager_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Marketing Manager", "cyan"))
for original_marketing_manager_value in original_marketing_manager_values:
    print(f"✅ {original_marketing_manager_value} → Marketing Manager")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Marketing Manager:", 'red'))
print(grouped_marketing_manager_values)

# Print summary
matched_count_marketing_manager = mask_marketing_manager_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Marketing Manager: "
        f"{matched_count_marketing_manager}",
        'red'))


import sys
import os
import re
import pandas as pd
from termcolor import colored
from tabulate import tabulate as tab

# Test dataframe
df_test = df.copy()

# _encode_decode.py

ENCODE_DECODE_MAP = {
    "&Aacute;": "Á",
    "&aacute;": "á",
    "&Eacute;": "É",
    "&eacute;": "é",
    "&Iacute;": "Í",
    "&iacute;": "í",
    "&Oacute;": "Ó",
    "&oacute;": "ó",
    "&Uacute;": "Ú",
    "&uacute;": "ú",
    "&Ntilde;": "Ñ",
    "&ntilde;": "ñ",
    "&Ccedil;": "Ç",
    "&ccedil;": "ç",
    "&quot;": "\"",
    "&amp;": "&",
    "&lt;": "<",
    "&gt;": ">",
    "&uuml;": "ü",
    "&Uuml;": "Ü",
    "&szlig;": "ß",
}


# Function to replace encoded values
def decode_html_entities(value):
    if isinstance(value, str):  # Only process strings
        for encoded, decoded in ENCODE_DECODE_MAP.items():
            value = value.replace(encoded, decoded)
    return value  # Return the modified or original value


# Apply the function to all string columns in the DataFrame
df['speciality'] = df['speciality'].apply(decode_html_entities)

from unidecode import unidecode
import unicodedata
import html

# encode and decode
df['speciality'] = df['speciality'].apply(lambda x: unidecode(html.unescape(str(x))))

# Trim whitespace
df['speciality'] = df['speciality'].str.strip()

# Remove extra spaces, underscores, and incorrect separators
df['speciality'] = df['speciality'].replace({
    r'\s{2,}': ' ',  # Replace multiple spaces with a single space
    r'[_\.]': ' ',   # Replace underscores and dots with space
    r',\s*': ' ',    # Remove commas followed by space
    r'\s*/\s*': '/', # Trim spaces around slashes
    r'[¡’]': '',     # Remove unwanted characters
    r'\b(?:And|and|&Amp;|&amp;)\b': '&'  # Normalize 'And' variations
}, regex=True)

# Normalize accented characters
df['speciality'] = df['speciality'].apply(
    lambda x: unicodedata.normalize('NFKD', x).encode('ascii', 'ignore').decode('utf-8')
    if isinstance(x, str) else x
)

# # Convert to title case
# df['speciality'] = df['speciality'].str.title()

# Tip: Use either one logical condition for the below normalize_text

# def normalize_text(text):
#     if isinstance(text, str):
#         # Normalize unicode characters (like accented characters)
#         text = unicodedata.normalize('NFKD', text)
#         # Remove special characters excluding '&' and '-'
#         text = text.encode('ascii', 'ignore').decode('utf-8')
#         # Remove unwanted special chars except for '&' and '-'
#         text = re.sub(r'[^\w\s&-]', '', text)
#         return text
#     return text


def normalize_text(text):
    if isinstance(text, str):
        # Normalize unicode characters (like accented characters)
        text = unicodedata.normalize('NFKD', text)
        # Remove unwanted special characters but add spaces where they were
        # First, replace unwanted characters with a space, then clean up the spaces
        text = re.sub(r'[^\w\s&-]', ' ', text)  # Replace non-alphanumeric with space
        # Replace multiple spaces with a single space
        text = re.sub(r'\s+', ' ', text)
        # Trim leading/trailing spaces
        text = text.strip()
        return text
    return text


df['speciality'] = df['speciality'].apply(normalize_text)  # Apply normalization

# Assuming your DataFrame is named df
# df['speciality'] = df['speciality'].str.strip()  # Trim leading and trailing spaces

# To handle Prime Data
# Apply transformation only where speciality starts with numbers
df['speciality'] = df['speciality'].apply(lambda x: re.sub(r'^\d+\s*', '', x) if isinstance(x, str) and re.match(r'^\d+', x) else x)

# List of specialities that should be updated to theme "GAS"
gas_specialities = [
    "Head Chef",
    "Pastry Chef Pastry Cook",
    "Executive Chef",
    "Wine & Spirits Industry",
    "Sous-Chef",
    'Culinary Consultant Consultant Chef',
    'Agricultural Producer',
    'Hotel Restaurant Equipment',
    'Sushi Chef',
    'Barman Bartender',
    'Baker',
    'Second de Cuisine',
    'Restaurant Hotel Manager',
    'Culinary Consultant',
    'Chef',
    'Other Food Industry',
    'Food & Beverage Manager',
    'Other Gastronomy Specialty',
    'Gastroenterologist'
]

# Update theme to 'GAS' for matching speciality values
df.loc[df['speciality'].isin(gas_specialities), 'theme'] = 'GAS'

# Filtering logic: Keep only non valid records in df_other dataframe
df_CWS = df[df['theme'] == 'GAS']

# Print low-confidence sample
print(colored("\nRecords where Theme = GAS", "red", attrs=["bold"]))
print(tab(df_CWS.head(10), headers='keys', tablefmt='psql'))
print(colored(f"\nRecords where Theme = GAS: {len(df_CWS)}", "red"))

# Create clean working columns
df['speciality'] = df['speciality'].fillna('Other').astype(str).str.strip()
df['speciality'] = df['speciality'].astype(str).str.strip().replace(['-', 'nan', '', 'Unknown', 'Unspecified Specialty'], 'Other')

# Filtering logic: Keep only non valid records in df_other dataframe
df_other = df[
    df['speciality'].astype(str).str.strip().isin([
        'Other',
        'Unknown',
        'None',
        'Medical Aesthetics Industry',
        'Other Industry',
        'Other Please specify',
        'Other please specify',
        'Dp',
        '-'
    ]) |  # Remove specified values
    df['speciality'].astype(str).str.match(r'^\d+$') |  # numbers only
    df['speciality'].astype(str).str.match(r'^[A-Za-z]$')  # single letters
].reset_index(drop=True)

# Remove records where Theme = GAS
df_other = df_other[df_other['theme'] != 'GAS']

# Print low-confidence sample
print(colored("\nRecords where Job Title is Other, Unknown, None or non relevant", "red", attrs=["bold"]))
print(tab(df_other.head(10), headers='keys', tablefmt='psql'))
print(colored(f"\nRecords where Job Title is Other, Unknown, None or non relevant: {len(df_other)}", "red"))

# Filtering logic: Keep only valid records in df
df = df[
    ~df['speciality'].astype(str).str.strip().isin([
        'Other',
        'Unknown',
        'None',
        'Medical Aesthetics Industry',
        'Other Industry',
        'Other Please specify',
        'Other please specify',
        'Dp',
        '-'
    ]) &  # Remove specified values
    ~df['speciality'].astype(str).str.match(r'^\d+$') &  # Remove numbers only
    ~df['speciality'].astype(str).str.match(r'^[A-Za-z]$')  # Remove single letters
].reset_index(drop=True)

# Remove records where Theme = GAS
df = df[df['theme'] != 'GAS']

# Print count of valid non-matching job titles that will be sent for machine learning process
print(colored(f"\nCount of records that will be sent for transformation stages: {df.shape[0]}", 'red'))

# Creating a copy column original_specialty to apply Machine Learning
df['original_speciality'] = df['speciality'].copy()





import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Sales related titles

sales_variants = [
    # Standard Titles & Variants
    r"(?i)\bSales\b",
    r"(?i)\bSales Representative\b",
    r"(?i)\bSales Manager\b",
    r"(?i)\bSales Director\b",
    r"(?i)\bSales Specialist\b",
    r"(?i)\bSales Executive\b",
    r"(?i)\bAccount Manager\b",
    r"(?i)\bBusiness Development Representative\b",
    r"(?i)\bSales Associate\b",
    r"(?i)\bAccount Executive\b",
    r"(?i)\bOperations Manager\b",
    r"(?i)\bRsm\b",
    r"(?i)\bAesthetic Accounting\b",
    r"(?i)\bSalesEvent Coordinator\b",
    r"(?i)Sales",
    r"(?i)Visitadora Medica",
    r"(?i)Sale Manager",
    r"(?i)Financial Manager",
    r"(?i)\bDemand Generation Manager\b",
    r"(?i)\bDirecteur Commercial\b",
    r"(?i)\bResponsavel Comercial\b",
    r"(?i)\bAccount Exec\b",
    r"(?i)\bCommercial\b",
    r"(?i)\bResponsable\b",
    r"(?i)\bSale\b",
    r"(?i)\bMgr Sr Dev - Botox Cosmetic Us Facial Aes Sales\b",
    r"(?i)\bE-Commerce\b",
    r"(?i)\bSalesClient\b",
    r"(?i)\bCommerciale\b",
    r"(?i)\bAccount Executive\b",

    # Misspellings & Typographical Errors
    r"(?i)\bSlaes\b",
    r"(?i)\bSals\b",
    r"(?i)\bSlaesman\b",
    r"(?i)\bSalesman\b",
    r"(?i)\bSalses\b",

    # Case Variations
    r"(?i)\bSALES\b",
    r"(?i)\bsales\b",
    r"(?i)\bSaLeS\b",
    r"(?i)\bSALESMAN\b",

    # Spanish Variants
    r"(?i)\bVentas\b",
    r"(?i)\bRepresentante de Ventas\b",
    r"(?i)\bGerente de Ventas\b",
    r"(?i)\bDirector de Ventas\b",
    r"(?i)\bEspecialista en Ventas\b",
    r"(?i)\bEjecutivo de Ventas\b",
    r"(?i)\bAsociado de Ventas\b",
    r"(?i)\bDesarrollo de Negocios en Ventas\b",
    r"(?i)\bRepresentante de Ventas\b",

    # Hybrid Spanish-English Variants
    r"(?i)\bSales Representante\b",
    r"(?i)\bSales Gerente de Ventas\b",
    r"(?i)\bSales Ejecutivo\b",
    r"(?i)\bBusiness Development Ventas\b",

    # Other Possible Variations (Doctor Forms, Specialist Forms)
    r"(?i)\bAccount Sales Manager\b",
    r"(?i)\bClient Relations Specialist\b",
    r"(?i)\bBusiness Development Sales\b",
    r"(?i)\bSales Lead Specialist\b",
    r"(?i)\bRegional Sales Manager\b",
    r"(?i)\bBilling Contact\b",
    r"(?i)\bAccountant\b",
    r"(?i)\bCOMMERICIAL ASSISTANT\b",
    r"(?i)Sales",
]

# Exact matches that should be updated
sales_exact_matches = {
    "Sales",
    "Sales Representative",
    "Sales Manager",
    "Sales Director",
    "Sales Specialist",
    "Sales Executive",
    "Account Manager",
    "Business Development Representative",
    "Sales Associate",
    "Slaes",
    "Sals",
    "Slaesman",
    "Salesman",
    "Salses",
    "SALES",
    "sales",
    "SaLeS",
    "SALESMAN",
    "Ventas",
    "Representante de Ventas",
    "Gerente de Ventas",
    "Director de Ventas",
    "Especialista en Ventas",
    "Ejecutivo de Ventas",
    "Asociado de Ventas",
    "Desarrollo de Negocios en Ventas",
    "Sales Representante",
    "Sales Gerente de Ventas",
    "Sales Ejecutivo",
    "Business Development Ventas",
    "Account Sales Manager",
    "Client Relations Specialist",
    "Business Development Sales",
    "Sales Lead Specialist",
    "Regional Sales Manager",
    "Specialized StoreConcept Store",
    'Account Coordinator',
    'Finance',
    'Account Director',
    'Group Account Director',
    'Commercialdirector',
    'Franchise Manager',
    'Comercial',
    'Dir Comercial',
    'National Accounts Director',
    'Teleshopping',
    'Ready-To-Wear Fashion Store',
    'Travel Retail Duty Free',
    'Account Directpr',
    'AE',
}

# # Define patterns (these should NOT be changed)
# sales_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

sales_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Sales
mask_sales = df['speciality'].str.contains('|'.join(sales_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(sales_exact_matches)

# mask_sales_exclusions = df['speciality'].str.contains(sales_exclusions, case=False, na=False, regex=True)
mask_sales_exclusions = df['speciality'].isin(sales_exclusions)

# Final mask: Select Sales
mask_sales_final = mask_sales & ~mask_sales_exclusions

# Store the original values that will be replaced
original_sales_values = df.loc[mask_sales_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_sales_final, 'speciality'] = 'Sales'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Sales", 'green'))
print(df.loc[mask_sales_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_sales_values = df.loc[mask_sales_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Sales", "cyan"))
for original_sales_value in original_sales_values:
    print(f"✅ {original_sales_value} → Sales")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Sales:", 'red'))
print(grouped_sales_values)

# Print summary
matched_count_sales = mask_sales_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Sales: "
        f"{matched_count_sales}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Registered Nurse (RN) related titles

RN_variants = [
    # Standard Titles & Variants
    r"(?i)\bRegistered Nurse\b",
    r"(?i)\bRegistered Nurse (RN)\b",
    r"(?i)\bRN\b",
    r"(?i)\bNurse (Registered)\b",
    r"(?i)\bRegistered Nurse Practitioner\b",
    r"(?i)\bRegistered Professional Nurse\b",
    r"(?i)\bNursing Specialist\b",
    r"(?i)\bRegistered Nurse RN\b",
    r"(?i)\bR N\b",
    r"(?i)\bRm\b",
    r"(?i)\bRegister Nurse\b",
    r"(?i)\bRegistered Cosmetic Nurse\b",
    r"(?i)\bRegistered Nursing\b",
    r"(?i)\bRegistered Staff Nurse\b",
    r"(?i)\bInjection\b",
    r"(?i)\bChargenurse\b",
    r"(?i)\bAdvanced Practice Registered Nurse\b",
    r"(?i)\bInfirmiere Auxiliaire\b",
    r"(?i)\bRegisterednurse\b",
    r"(?i)\bPrescribing Nurse\b",
    r"(?i)\bRegistered General Nurse\b",
    r"(?i)\bOperatsionnaia Medsestra\b",
    r"(?i)\bInfirmiere\b",
    r"(?i)\bMidwife\b",
    r"(?i)\bEnfermeira\b",
    r"(?i)\bEnfermagem Estetica\b",
    r"(?i)\bEmergencyroomnurse\b",
    r"(?i)\bRnPmhnp\b",

    # Misspellings & Typographical Errors
    r"(?i)\bRegistred Nurse\b",
    r"(?i)\bRegisted Nurse\b",
    r"(?i)\bRegitered Nurse\b",
    r"(?i)\bResgistered Nurse\b",
    r"(?i)\bRegistred Nurce\b",
    r"(?i)\bRergistered Nurse\b",
    r"(?i)\bRegistered Nure\b",
    r"(?i)\bRegistered Nuerse\b",

    # Case Variations
    r"(?i)\bREGISTERED NURSE\b",
    r"(?i)\bREGISTERED NURSE (RN)\b",
    r"(?i)\bregistered nurse\b",
    r"(?i)\bREGISTERED nurse\b",

    # Spanish Variants
    r"(?i)\bEnfermera Registrada\b",
    r"(?i)\bEnfermera Profesional Registrada\b",
    r"(?i)\bEnfermera (RN)\b",
    r"(?i)\bEnfermera Especialista\b",
    r"(?i)\bEnfermera Registrada (RN)\b",
    r"(?i)\bEnfermera de Cuidados Críticos\b",

    # Hybrid Spanish-English Variants
    r"(?i)\bRegistered Enfermera\b",
    r"(?i)\bNurse Registrada (RN)\b",

    # Other Possible Variations (Doctor Forms, Specialist Forms)
    r"(?i)\bNurse Practitioner (Registered)\b",
    r"(?i)\bNurse Consultant\b",
    r"(?i)\bCertified Registered Nurse (CRN)\b",
    r"(?i)\bRegistered Nursing Assistant\b",
    r"(?i)\bNurse Educator\b",
    r"(?i)\bNursing Supervisor\b",
    r"(?i)\bCommunity Nurse\b",
    r"(?i)\bCritical Care Nurse (RN)\b",
    r"(?i)\bEmergency Nurse (RN)\b",
    r"(?i)\bCosmetic NurseRegistered Nurse\b",
]

# Exact matches that should be updated
RN_exact_matches = {
    "Registered Nurse",
    "Registered Nurse (RN)",
    "RN",
    "Nurse (Registered)",
    "Registered Nurse Practitioner",
    "Registered Professional Nurse",
    "Nursing Specialist",
    "Registred Nurse",
    "Registed Nurse",
    "Regitered Nurse",
    "Resgistered Nurse",
    "Registred Nurce",
    "Rergistered Nurse",
    "Registered Nure",
    "Registered Nuerse",
    "Enfermera Registrada",
    "Enfermera Profesional Registrada",
    "Enfermera (RN)",
    "Enfermera Especialista",
    "Enfermera Registrada (RN)",
    "Enfermera de Cuidados Críticos",
    "Registered Enfermera",
    "Nurse Registrada (RN)",
    "Nurse Practitioner (Registered)",
    "Nurse Consultant",
    "Certified Registered Nurse (CRN)",
    "Registered Nursing Assistant",
    "Nurse Educator",
    "Nursing Supervisor",
    "Community Nurse",
    "Critical Care Nurse (RN)",
    "Emergency Nurse (RN)",
    "Aesthetic Nurse",
    "Registered Nurse RN",
    'Registered NurseClinical Director',
    'Rgn',
    'Aesthetic RNOwner',
    'Advanced Practice Aesthetic RN',
    'Certified Aesthetic Nurse Specialist Independent Contractor',
    'Emt',
    'Aesthetic Nurse & Clinic CEO',
    'Aesthetic nurse',
    'Enfermera',
}

# # Define patterns (these should NOT be changed)
RN_exclusions = r'\b(?:ARNP)|(?:Arpn)|(?:Advanced)|(?:Licensed)\b'

# RN_exclusions = {
#     'Resident', 'resident', 'student', 'Trainee', 'Resident Doctor', 'Resident ooPhysician',
#     'Intern', 'intern', 'Medical Intern', 'Fellow', 'fellow', 'Clinical Fellow', 'Medical Student',
#     'Clinical Trainee', 'Trainee Doctor', 'Trainee Physician', 'Junior Doctor', 'Postgraduate Trainee',
#     'Aesthetic Fellow', 'Aesthetic Trainee', 'Aesthetic Medicine Fellow', 'Aesthetic Resident'
# }

# Create a mask for Registered Nurse (RN)
mask_RN = df['speciality'].str.contains('|'.join(RN_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(RN_exact_matches)

mask_RN_exclusions = df['speciality'].str.contains(RN_exclusions, case=False, na=False, regex=True)
# mask_RN_exclusions = df['speciality'].isin(RN_exclusions)

# Final mask: Select Registered Nurse (RN)
mask_RN_final = mask_RN & ~mask_RN_exclusions

# Store the original values that will be replaced
original_RN_values = df.loc[mask_RN_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_RN_final, 'speciality'] = 'Registered Nurse (RN)'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Registered Nurse (RN)", 'green'))
print(df.loc[mask_RN_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_RN_values = df.loc[mask_RN_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Registered Nurse (RN)", "cyan"))
for original_RN_value in original_RN_values:
    print(f"✅ {original_RN_value} → Registered Nurse (RN)")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Registered Nurse (RN):", 'red'))
print(grouped_RN_values)

# Print summary
matched_count_RN = mask_RN_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Registered Nurse (RN): "
        f"{matched_count_RN}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Hematologist related titles

hematologist_variants = [
    r"(?i)\bHematologist\b",  # Standard title

    # Common misspellings and case errors
    r"(?i)\bHaematologist\b",
    r"(?i)\bHematoligst\b",
    r"(?i)\bHemotologist\b",
    r"(?i)\bHematlogist\b",
    r"(?i)\bHematolgist\b",
    r"(?i)\bHematoloigst\b",

    # Spanish variants
    r"(?i)\bHematólogo\b",
    r"(?i)\bEspecialista\s?en\s?Hematología\b",

    # Other possible variations
    r"(?i)\bBlood\s?Doctor\b",
    r"(?i)\bHematology\s?Specialist\b",
    r"(?i)\bDoctor\s?of\s?Hematology\b",
    r"(?i)\bHematology\s?Consultant\b",
]

# Exact matches that should be updated
hematologist_exact_matches = {
    "Hematologist",
    "Haematologist",
    "Hematoligst",
    "Hemotologist",
    "Hematlogist",
    "Hematolgist",
    "Hematoloigst",
    # Spanish variants
    "Hematólogo",
    "Especialista en Hematología",
    # Other possible variations
    "Blood Doctor",
    "Hematology Specialist",
    "Doctor of Hematology",
    "Hematology Consultant",
    'Hematology',
}

# Define patterns (these should NOT be changed)
hematologist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Hematologist
mask_hematologist = df['speciality'].str.contains('|'.join(hematologist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(hematologist_exact_matches)
mask_hematologist_exclusions = df['speciality'].isin(hematologist_exclusions)

# Final mask: Select Hematologist
mask_hematologist_final = mask_hematologist & ~mask_hematologist_exclusions

# Store the original values that will be replaced
original_hematologist_values = df.loc[mask_hematologist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_hematologist_final, 'speciality'] = 'Hematologist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Hematologist", 'green'))
print(df.loc[mask_hematologist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_hematologist_values = df.loc[mask_hematologist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Hematologist", "cyan"))
for original_hematologist_value in original_hematologist_values:
    print(f"✅ {original_hematologist_value} → Hematologist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Hematologist:", 'red'))
print(grouped_hematologist_values)

# Print summary
matched_count_hematologist = mask_hematologist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Hematologist: "
        f"{matched_count_hematologist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Photographer related titles

photographer_variants = [
    # Standard Titles & Variants
    r"(?i)\bPhotographer\b",
    r"(?i)\bProfessional Photographer\b",
    r"(?i)\bPhotographer Specialist\b",
    r"(?i)\bPhotography Expert\b",
    r"(?i)\bPhotography Consultant\b",
    r"(?i)\bConsultant Photographer\b",
    r"(?i)\bPhotographic Artist\b",

    # Misspellings & Typographical Errors
    r"(?i)\bFotographer\b",
    r"(?i)\bPhographer\b",
    r"(?i)\bPhotogarpher\b",
    r"(?i)\bPhotographer\b",
    r"(?i)\bPhotograhper\b",

    # Case Variations
    r"(?i)\bphotographer\b",
    r"(?i)\bPHOTOGRAPHER\b",
    r"(?i)\bPhOtOgRaPhEr\b",
    r"(?i)\bPhoToGrApHeR\b",

    # Spanish Variants
    r"(?i)\bFotógrafo\b",
    r"(?i)\bFotógrafa\b",
    r"(?i)\bFotógrafo Profesional\b",
    r"(?i)\bEspecialista en Fotografía\b",
    r"(?i)\bExperto en Fotografía\b",
    r"(?i)\bConsultor de Fotografía\b",
    r"(?i)\bConsultor Fotográfico\b",
    r"(?i)\bArtista Fotográfico\b",

    # Other Possible Variations
    r"(?i)\bPhotographic Specialist\b",
    r"(?i)\bPhotographic Consultant\b",
    r"(?i)\bPhotography Artist\b",
    r"(?i)\bPhotography Professional\b",
]

# Exact matches that should be updated
photographer_exact_matches = {
    "Photographer",
    "Professional Photographer",
    "Photographer Specialist",
    "Photography Expert",
    "Photography Consultant",
    "Consultant Photographer",
    "Photographic Artist",
    "Fotographer",
    "Phographer",
    "Photogarpher",
    "Photograhper",
    "Fotógrafo",
    "Fotógrafa",
    "Fotógrafo Profesional",
    "Especialista en Fotografía",
    "Experto en Fotografía",
    "Consultor de Fotografía",
    "Consultor Fotográfico",
    "Artista Fotográfico",
    "Photographic Specialist",
    "Photographic Consultant",
    "Photography Artist",
    "Photography Professional",
}

# # Define patterns (these should NOT be changed)
# photographer_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

photographer_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Photographer
mask_photographer = df['speciality'].str.contains('|'.join(photographer_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(photographer_exact_matches)

# mask_photographer_exclusions = df['speciality'].str.contains(photographer_exclusions, case=False, na=False, regex=True)
mask_photographer_exclusions = df['speciality'].isin(photographer_exclusions)

# Final mask: Select Photographer
mask_photographer_final = mask_photographer & ~mask_photographer_exclusions

# Store the original values that will be replaced
original_photographer_values = df.loc[mask_photographer_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_photographer_final, 'speciality'] = 'Photographer'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Photographer", 'green'))
print(df.loc[mask_photographer_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_photographer_values = df.loc[mask_photographer_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Photographer", "cyan"))
for original_photographer_value in original_photographer_values:
    print(f"✅ {original_photographer_value} → Photographer")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Photographer:", 'red'))
print(grouped_photographer_values)

# Print summary
matched_count_photographer = mask_photographer_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Photographer: "
        f"{matched_count_photographer}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Internal Medicine related titles

internal_medicine_variants = [
    r"(?i)\bInternal\s?Medicine\b",
    r"(?i)\bInternal\s?Med\b",

    # Common misspellings and case errors
    r"(?i)\bInteral\s?Medicine\b",
    r"(?i)\bInternel\s?Medicine\b",
    r"(?i)\bInternl\s?Medicine\b",
    r"(?i)\bInternall\s?Medicine\b",
    r"(?i)\bIntarnal\s?Medicine\b",
    r"(?i)\bInteranl\s?Medicine\b",
    r"(?i)\bInternist\b",

    # Spanish variants
    r"(?i)\bMedicina\s?Interna\b",
    r"(?i)\bMédico\s?Internista\b",
    r"(?i)\bEspecialista\s?en\s?Medicina\s?Interna\b",

    # Other possible variations
    r"(?i)\bInternal\s?Medicine\s?Specialist\b",
    r"(?i)\bInternal\s?Medicine\s?Physician\b",
    r"(?i)\bInternal\s?Medicine\s?Doctor\b",
    r"(?i)\bBoard\s?Certified\s?Internist\b",
    r"(?i)\bInterne En Medecine\b",
    r"(?i)\bInfectious Diseases\b",
    r"(?i)\bInternal Medicine\b",
    r"(?i)\bConsultant U Internal Medicine\b",
    r"(?i)\bConsultant Internal Medicine\b",
    r"(?i)\bInfectious Diseases Specialist\b",
    r"(?i)\bInfection Control Specialist\b",
    r"(?i)\bMedico Estetico  Specialista In Medicina Interna\b",
    r"(?i)\bInterne En Medecine\b",
    r"(?i)\bInternist\b",
    r"(?i)\bCardiology Internal Medicine\b",
    r"(?i)\bMedical Doctor Internal Medicine\b",
    r"(?i)\bGeneral Internal Medicine\b",
    r"(?i)\bToxopherese  Environmental Medicine  Internal Medicine  Anti-Aging Medicine\b",
    r"(?i)\bInternist- Aesthetic Medicine Master\b",
    r"(?i)\bMedicina Interna\b",
    r"(?i)\bInternal Medicine Dermatology\b",
    r"(?i)\bInternal Med\b",
    r"(?i)\bMedicina Interna Estetica\b",
    r"(?i)\bInternal Medicine & Lifestyle Medicine\b",
]

# Exact matches that should be updated
internal_medicine_exact_matches = {
    "Internal Medicine",
    "Internal Med",
    # Misspellings
    "Interal Medicine",
    "Internel Medicine",
    "Internl Medicine",
    "Internall Medicine",
    "Intarnal Medicine",
    "Interanl Medicine",
    "Internist",
    # Spanish variants
    "Medicina Interna",
    "Médico Internista",
    "Especialista en Medicina Interna",
    # Other possible variations
    "Internal Medicine Specialist",
    "Internal Medicine Physician",
    "Internal Medicine Doctor",
    "Board Certified Internist",
    'Infection Control',
    'infection control',
    'Int Medicine',
    'Osteopathic Physician Specializing In Functional Internal & Regenerative Medicine',
}

# Define patterns (these should NOT be changed)
internal_medicine_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Physician Recruiter - Otolaryngology Ent & Internal Medicine Consultant',
    'Physician Assistant In Internal Medicine',
    'Physician Recruiter - Anesthesiology Family & Internal Medicine Consultant',
}

# Create a mask for Internal Medicine
mask_internal_medicine = df['speciality'].str.contains('|'.join(internal_medicine_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(internal_medicine_exact_matches)
mask_internal_medicine_exclusions = df['speciality'].isin(internal_medicine_exclusions)

# Final mask: Select Internal Medicine
mask_internal_medicine_final = mask_internal_medicine & ~mask_internal_medicine_exclusions

# Store the original values that will be replaced
original_internal_medicine_values = df.loc[mask_internal_medicine_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_internal_medicine_final, 'speciality'] = 'Internal Medicine'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Internal Medicine", 'green'))
print(df.loc[mask_internal_medicine_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_internal_medicine_values = df.loc[mask_internal_medicine_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Internal Medicine", "cyan"))
for original_internal_medicine_value in original_internal_medicine_values:
    print(f"✅ {original_internal_medicine_value} → Internal Medicine")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Internal Medicine:", 'red'))
print(grouped_internal_medicine_values)

# Print summary
matched_count_internal_medicine = mask_internal_medicine_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Internal Medicine: "
        f"{matched_count_internal_medicine}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Oculoplastic Surgeon related titles

oculoplastic_surgeon_variants = [
    # Standard Titles & Abbreviations
    r"(?i)\bOculoplastic\s?Surgeon\b",
    r"(?i)\bOculoplastics\s?Surgeon\b",
    r"(?i)\bOculo-Plastic\s?Surgeon\b",
    r"(?i)\bOphthalmic\s?Plastic\s?Surgeon\b",
    r"(?i)\bOrbital\s?Surgeon\b",
    r"(?i)\bOculofacial\s?Surgeon\b",
    r"(?i)\bEyelid\s?Surgeon\b",
    r"(?i)\bFacial\s?Oculoplastic\s?Surgeon\b",
    r"(?i)\bOculoplastic\s?Specialist\b",
    r"(?i)\bOculoplasty Surgeon\b",
    r"(?i)\bOphthalmologistOculoplastic Surgeon\b",
    r"(?i)\bOphthalmoplastic Surgery\b",
    r"(?i)\bOculoplastic\b",

    # Misspellings & Typographical Errors
    r"(?i)\bOcculoplastic\s?Surgeon\b",
    r"(?i)\bOculaplastic\s?Surgeon\b",
    r"(?i)\bOculoplastik\s?Surgeon\b",
    r"(?i)\bOculoplastic\s?Surgon\b",
    r"(?i)\bOculoplastic\s?Surgin\b",
    r"(?i)\bOculoplastic\s?Surjeon\b",
    r"(?i)\bOculoplastic\s?Surgan\b",
    r"(?i)\bOculoplastic\s?Surgion\b",
    r"(?i)\bOculoplastic\s?Suergeon\b",
    r"(?i)\bOculoplastic\s?Srurgeon\b",
    r"(?i)\bOculoplastic\s?Surrgeon\b",

    # Case Variations
    r"(?i)\boculoplastic surgeon\b",
    r"(?i)\bOculoplastic surgeon\b",
    r"(?i)\boculoplastic Surgeon\b",
    r"(?i)\bOCULOPLASTIC SURGEON\b",
    r"(?i)\bOculoPlastic Surgeon\b",

    # Spanish Variants
    r"(?i)\bCirujano\s?Oculoplástico\b",
    r"(?i)\bEspecialista\s?Oculoplástico\b",
    r"(?i)\bMédico\s?Cirujano\s?Oculoplástico\b",
    r"(?i)\bDoctor\s?en\s?Cirugía\s?Oculoplástica\b",
    r"(?i)\bCirujano\s?Plástico\s?Oftálmico\b",

    # Other Possible Variations (Including Doctor/Specialist Titles)
    r"(?i)\bEyelid\s?Plastic\s?Surgeon\b",
    r"(?i)\bOrbital\s?Facial\s?Plastic\s?Surgeon\b",
    r"(?i)\bOphthalmic\s?Cosmetic\s?Surgeon\b",
    r"(?i)\bPeriorbital\s?Surgeon\b",
    r"(?i)\bOculoplastics\b",
    r"(?i)\bAesthetic Medicine Oculoplasty  Ophtalmology\b",
    r"(?i)\bOculofacial Surgery\b",
]

# Exact matches that should be updated
oculoplastic_surgeon_exact_matches = {
    "Oculoplastic Surgeon",
    "Oculoplastics Surgeon",
    "Oculo-Plastic Surgeon",
    "Ophthalmic Plastic Surgeon",
    "Orbital Surgeon",
    "Oculofacial Surgeon",
    "Eyelid Surgeon",
    "Facial Oculoplastic Surgeon",
    "Oculoplastic Specialist",
    "Occuloplastic Surgeon",
    "Oculaplastic Surgeon",
    "Oculoplastik Surgeon",
    "Oculoplastic Surgon",
    "Oculoplastic Surgin",
    "Oculoplastic Surjeon",
    "Oculoplastic Surgan",
    "Oculoplastic Surgion",
    "Oculoplastic Suergeon",
    "Oculoplastic Srurgeon",
    "Oculoplastic Surrgeon",
    "Cirujano Oculoplástico",
    "Especialista Oculoplástico",
    "Médico Cirujano Oculoplástico",
    "Doctor en Cirugía Oculoplástica",
    "Cirujano Plástico Oftálmico",
    "Eyelid Plastic Surgeon",
    "Orbital Facial Plastic Surgeon",
    "Ophthalmic Cosmetic Surgeon",
    "Periorbital Surgeon",
}

# # Define patterns (these should NOT be changed)
# oculoplastic_surgeon_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

oculoplastic_surgeon_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Oculoplastic Surgeon
mask_oculoplastic_surgeon = df['speciality'].str.contains('|'.join(oculoplastic_surgeon_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(oculoplastic_surgeon_exact_matches)

# mask_oculoplastic_surgeon_exclusions = df['speciality'].str.contains(oculoplastic_surgeon_exclusions, case=False, na=False, regex=True)
mask_oculoplastic_surgeon_exclusions = df['speciality'].isin(oculoplastic_surgeon_exclusions)

# Final mask: Select Oculoplastic Surgeon
mask_oculoplastic_surgeon_final = mask_oculoplastic_surgeon & ~mask_oculoplastic_surgeon_exclusions

# Store the original values that will be replaced
original_oculoplastic_surgeon_values = df.loc[mask_oculoplastic_surgeon_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_oculoplastic_surgeon_final, 'speciality'] = 'Oculoplastic Surgeon'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Oculoplastic Surgeon", 'green'))
print(df.loc[mask_oculoplastic_surgeon_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_oculoplastic_surgeon_values = df.loc[mask_oculoplastic_surgeon_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Oculoplastic Surgeon", "cyan"))
for original_oculoplastic_surgeon_value in original_oculoplastic_surgeon_values:
    print(f"✅ {original_oculoplastic_surgeon_value} → Oculoplastic Surgeon")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Oculoplastic Surgeon:", 'red'))
print(grouped_oculoplastic_surgeon_values)

# Print summary
matched_count_oculoplastic_surgeon = mask_oculoplastic_surgeon_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Oculoplastic Surgeon: "
        f"{matched_count_oculoplastic_surgeon}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Event Manager related titles

event_manager_variants = [
    r"(?i)\bevent\s?manager\b",
    r"(?i)\bevent\s?planner\b",
    r"(?i)\bevent\s?coordinator\b",
    r"(?i)\bevent\s?supervisor\b",
    r"(?i)\bevent\s?director\b",
    r"(?i)\bevent\s?organizer\b",
    r"(?i)\bevent\s?planning\s?manager\b",
    r"(?i)\bevent\s?production\s?manager\b",
    r"(?i)\bevent\s?operations\s?manager\b",
    r"(?i)\bevent\s?staff\s?manager\b",
    r"(?i)\bevent\s?marketing\s?manager\b",
    r"(?i)\bevent\s?project\s?manager\b",
    r"(?i)\bevent\s?management\s?specialist\b",
    r"(?i)\bevent\s?consultant\b",
    r"(?i)\bevent\s?strategist\b",
    r"(?i)\bevent\s?administrator\b",
    r"(?i)\bTrade Show\b",
    r"(?i)\bEvents Manager\b",
    r"(?i)Events",
    r"(?i)Tradeshow",
    r"(?i)Exhibition Manager",
    r"(?i)\bChef De Projet Congres\b",
    r"(?i)\bConfirm The Booth\b",
    r"(?i)Mice",
    r"(?i)Teamlead Congresses",
    r"(?i)Conference Producer",
    r"(?i)Booth Staff",
    r"(?i)Exhibitions",
    r"(?i)Exhibition",
    r"(?i)\bCongress Agency\b",
    r"(?i)\bCongress\b",
    r"(?i)\bExpo Man\b",
    r"(?i)\bOnsite Registration Support\b",
    r"(?i)\bSymposia&Congress Expert\b",
    r"(?i)\bConference\b",
    r"(?i)\bEvent Booking\b",
    r"(?i)\bHost\b",
    r"(?i)\bEvent Services Manager\b",
    r"(?i)\bExhibit Planning\b",
    r"(?i)\bEvent Assistant\b",
    r"(?i)\bEvent Planning\b",
    r"(?i)\bConvention Coordinator\b",
    r"(?i)\bConvention Manager\b",

    # Spanish variants
    r"(?i)\bgerente\s?de\s?eventos\b",  # Spanish form (event manager)
    r"(?i)\bplanificador\s?de\s?eventos\b",  # Spanish form (event planner)
    r"(?i)\bcoordinador\s?de\s?eventos\b",  # Spanish form (event coordinator)
    r"(?i)\borganizador\s?de\s?eventos\b",  # Spanish form (event organizer)
    r"(?i)\bdirector\s?de\s?eventos\b",  # Spanish form (event director)
    r"(?i)\bresponsable\s?de\s?eventos\b",  # Spanish form (event supervisor)
    r"(?i)\bplanificador\s?de\s?eventos\s?certificado\b",  # Spanish form (certified event planner)
    r"(?i)\bcoordinador\s?de\s?eventos\s?profesional\b",  # Spanish form (professional event coordinator)
    r"(?i)\bcoordinador\s?de\s?eventos\s?certificado\b",  # Spanish form (certified event coordinator)

    # Other possible variations
    r"(?i)\bmanager\s?of\s?events\b",
    r"(?i)\bplanner\s?of\s?events\b",
    r"(?i)\bcoordinator\s?of\s?events\b",
    r"(?i)\bevent\s?project\s?coordinator\b",
    r"(?i)\bevent\s?program\s?manager\b",
    r"(?i)\bcelebration\s?planner\b",
    r"(?i)\bconference\s?organizer\b",
    r"(?i)\bfestival\s?organizer\b",
    r"(?i)\bmeeting\s?planner\b",
    r"(?i)\bparty\s?planner\b",
    r"(?i)\bconference\s?manager\b",
    r"(?i)\bconvention\s?planner\b",
    r"(?i)\bcorporate\s?event\s?manager\b",
]

# Exact matches that should be updated
event_manager_exact_matches = {
    "Event Manager",
    "Event Planner",
    "Event Coordinator",
    "Event Supervisor",
    "Event Director",
    "Event Organizer",
    "Event Planning Manager",
    "Event Production Manager",
    "Event Operations Manager",
    "Event Staff Manager",
    "Event Marketing Manager",
    "Event Project Manager",
    "Event Management Specialist",
    "Event Consultant",
    "Event Strategist",
    "Event Administrator",
    # Spanish form matches
    "Gerente de Eventos",
    "Planificador de Eventos",
    "Coordinador de Eventos",
    "Organizador de Eventos",
    "Director de Eventos",
    "Responsable de Eventos",
    "Planificador de Eventos Certificado",
    "Coordinador de Eventos Profesional",
    "Coordinador de Eventos Certificado",
    'Attendee Manager',
    'Meeting Producer',
    'Show Coordinator',
    'Booth Operator',
    'Director of Conferences Logistics',
}

# Define patterns (these should NOT be changed)
event_manager_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Event Manager
mask_event_manager = df['speciality'].str.contains('|'.join(event_manager_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(event_manager_exact_matches)
mask_event_manager_exclusions = df['speciality'].isin(event_manager_exclusions)

# Final mask: Select Event Manager
mask_event_manager_final = mask_event_manager & ~mask_event_manager_exclusions

# Store the original values that will be replaced
original_event_manager_values = df.loc[mask_event_manager_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_event_manager_final, 'speciality'] = 'Event Manager'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Event Manager", 'green'))
print(df.loc[mask_event_manager_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_event_manager_values = df.loc[mask_event_manager_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Event Manager", "cyan"))
for original_event_manager_value in original_event_manager_values:
    print(f"✅ {original_event_manager_value} → Event Manager")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Event Manager:", 'red'))
print(grouped_event_manager_values)

# Print summary
matched_count_event_manager = mask_event_manager_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Event Manager: "
        f"{matched_count_event_manager}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Trichologist related titles

trichologist_variants = [
    # Standard Titles & Variants
    r"(?i)\bTrichologist\b",  # General term for Trichologist
    r"(?i)\bHair Specialist\b",  # Common alternative for trichologist
    r"(?i)\bHair Doctor\b",  # Informal term for trichologist
    r"(?i)\bScalp Specialist\b",  # Related to scalp care and treatment
    r"(?i)\bScalp Care Master\b",
    r"(?i)\bHair Science\b",
    r"(?i)Trichology",

    # Misspellings & Typographical Errors
    r"(?i)\bTricholgist\b",  # Common misspelling
    r"(?i)\bTricholist\b",  # Another common misspelling
    r"(?i)\bTricholigist\b",  # Another misspelling
    r"(?i)\bTrichologyst\b",  # Adding unnecessary 'y' at the end
    r"(?i)\bTrichollogist\b",  # Extra 'l' typo

    # Case Variations
    r"(?i)\bTRICHOLOGIST\b",  # Uppercase variant
    r"(?i)\btrichologist\b",  # Lowercase variant
    r"(?i)\bTrIcHoLoGiSt\b",  # Mixed case variant

    # Spanish Variants
    r"(?i)\bTricólogo\b",  # General term for trichologist in Spanish
    r"(?i)\bEspecialista en Cabello\b",  # Hair Specialist in Spanish
    r"(?i)\bEspecialista en Cuero Cabelludo\b",  # Scalp Specialist in Spanish

    # Hybrid Spanish-English Variants
    r"(?i)\bTrichologist Especialista en Cabello\b",  # Hybrid term
    r"(?i)\bTricólogo Hair Specialist\b",  # Hybrid term

    # Other Possible Variations (Doctor Forms, Specialist Forms)
    r"(?i)\bHair Care Doctor\b",  # General medical term for hair-related care
    r"(?i)\bHair and Scalp Specialist\b",  # Comprehensive term for both hair and scalp specialists
    r"(?i)\bScalp Care Physician\b",  # Doctor specializing in scalp care
]

# Exact matches that should be updated
trichologist_exact_matches = {
    "Trichologist",
    "Hair Specialist",
    "Hair Doctor",
    "Scalp Specialist",
    "Tricholgist",
    "Tricholist",
    "Tricholigist",
    "Trichologyst",
    "Trichollogist",
    "TRICHOLOGIST",
    "trichologist",
    "TrIcHoLoGiSt",
    "Tricólogo",
    "Especialista en Cabello",
    "Especialista en Cuero Cabelludo",
    "Trichologist Especialista en Cabello",
    "Tricólogo Hair Specialist",
    "Hair Care Doctor",
    "Hair and Scalp Specialist",
    "Scalp Care Physician",
    'Facial Aesthetics & Hair Loss',
    'Hair Loss',
}

# # Define patterns (these should NOT be changed)
# trichologist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

trichologist_exclusions = {
    'Resident', 'resident', 'student', 'Trainee', 'Resident Doctor', 'Resident ooPhysician',
    'Intern', 'intern', 'Medical Intern', 'Fellow', 'fellow', 'Clinical Fellow', 'Medical Student',
    'Clinical Trainee', 'Trainee Doctor', 'Trainee Physician', 'Junior Doctor', 'Postgraduate Trainee',
    'Aesthetic Fellow', 'Aesthetic Trainee', 'Aesthetic Medicine Fellow', 'Aesthetic Resident'
}

# Create a mask for Trichologist
mask_trichologist = df['speciality'].str.contains('|'.join(trichologist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(trichologist_exact_matches)

# mask_trichologist_exclusions = df['speciality'].str.contains(trichologist_exclusions, case=False, na=False, regex=True)
mask_trichologist_exclusions = df['speciality'].isin(trichologist_exclusions)

# Final mask: Select Trichologist
mask_trichologist_final = mask_trichologist & ~mask_trichologist_exclusions

# Store the original values that will be replaced
original_trichologist_values = df.loc[mask_trichologist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_trichologist_final, 'speciality'] = 'Trichologist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Trichologist", 'green'))
print(df.loc[mask_trichologist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_trichologist_values = df.loc[mask_trichologist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Trichologist", "cyan"))
for original_trichologist_value in original_trichologist_values:
    print(f"✅ {original_trichologist_value} → Trichologist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Trichologist:", 'red'))
print(grouped_trichologist_values)

# Print summary
matched_count_trichologist = mask_trichologist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Trichologist: "
        f"{matched_count_trichologist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Legal Counsel related titles

legal_counsel_variants = [
    r"(?i)\bLegal\s?Counsel\b",
    r"(?i)\bCounselor\b",
    r"(?i)\bLegal\s?Advisor\b",
    r"(?i)\bIn-House\s?Counsel\b",
    r"(?i)\bGeneral\s?Counsel\b",
    r"(?i)\bCorporate\s?Counsel\b",

    # Misspellings and case errors
    r"(?i)\bLegel\s?Counsel\b",
    r"(?i)\bLegel\s?Cousel\b",
    r"(?i)\bLagal\s?Counsel\b",
    r"(?i)\bLega\s?Counsel\b",
    r"(?i)\bLegal\s?Consel\b",

    # Spanish variants
    r"(?i)\bAsesor\s?Legal\b",
    r"(?i)\bConsejero\s?Legal\b",
    r"(?i)\bConsejero\s?Jurídico\b",
    r"(?i)\bAbogado\s?Corporativo\b",
    r"(?i)\bAsesor\s?Corporativo\b",
    r"(?i)\bAsesor\s?In-House\b",

    # Other possible variations
    r"(?i)\bContract\s?Counsel\b",
    r"(?i)\bLitigation\s?Counsel\b",
    r"(?i)\bEmployment\s?Counsel\b",
    r"(?i)\bTax\s?Counsel\b",
    r"(?i)\bLegal\s?Consultant\b",
    r"(?i)\bCompliance\s?Counsel\b",
    r"(?i)\bMergers\s?and\s?Acquisitions\s?Counsel\b",
    r"(?i)Regulatory Affairs",
    r"(?i)\bInternational Affairs Lead\b",
    r"(?i)\bCharge DAffaires\b",
    r"(?i)\bManager - Regulatory Compliance & Clinical Science Liaison\b",
    r"(?i)\bHead Corporate Affairs\b",
    r"(?i)\bAccreditation Officer\b",
    r"(?i)\bTranslater\b",
    r"(?i)\bRegistrar\b",
    r"(?i)\bAuditor\b",
    r"(?i)\bEquity\b",
    r"(?i)\bCompliance\b",
    r"(?i)\bScientific Document Management Associate\b",
    r"(?i)\bTranslator\b",
    r"(?i)\bLegal Assistant\b",
    r"(?i)\bManager of External Affairs\b",
]

# Exact matches that should be updated
legal_counsel_exact_matches = {
    "Legal Counsel",
    "Counselor",
    "Legal Advisor",
    "In-House Counsel",
    "General Counsel",
    "Corporate Counsel",
    # Misspellings and case errors
    "Legel Counsel",
    "Legel Cousel",
    "Lagal Counsel",
    "Lega Counsel",
    "Legal Consel",
    # Spanish variants
    "Asesor Legal",
    "Consejero Legal",
    "Consejero Jurídico",
    "Abogado Corporativo",
    "Asesor Corporativo",
    "Asesor In-House",
    # Other possible variations
    "Contract Counsel",
    "Litigation Counsel",
    "Employment Counsel",
    "Tax Counsel",
    "Legal Consultant",
    "Compliance Counsel",
    "Mergers and Acquisitions Counsel",
    'Medical Writer',
    'Writing',
    'Director Public Affairs',
    'Interpreting',
    'Corporate Advisor',
}

# Define patterns (these should NOT be changed)
legal_counsel_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Dermatology Health Equity Marketing Lead',
}

# Create a mask for Legal Counsel
mask_legal_counsel = df['speciality'].str.contains('|'.join(legal_counsel_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(legal_counsel_exact_matches)
mask_legal_counsel_exclusions = df['speciality'].isin(legal_counsel_exclusions)

# Final mask: Select Legal Counsel
mask_legal_counsel_final = mask_legal_counsel & ~mask_legal_counsel_exclusions

# Store the original values that will be replaced
original_legal_counsel_values = df.loc[mask_legal_counsel_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_legal_counsel_final, 'speciality'] = 'Legal Counsel'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Legal Counsel", 'green'))
print(df.loc[mask_legal_counsel_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_legal_counsel_values = df.loc[mask_legal_counsel_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Legal Counsel", "cyan"))
for original_legal_counsel_value in original_legal_counsel_values:
    print(f"✅ {original_legal_counsel_value} → Legal Counsel")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Legal Counsel:", 'red'))
print(grouped_legal_counsel_values)

# Print summary
matched_count_legal_counsel = mask_legal_counsel_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Legal Counsel: "
        f"{matched_count_legal_counsel}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Oral and Maxillofacial Surgeon related titles

oral_maxillofacial_variants = [
    # Standard Titles & Abbreviations
    r"(?i)\bOral\s?and\s?Maxillofacial\s?Surgeon\b",
    r"(?i)\bOral\s?&\s?Maxillofacial\s?Surgeon\b",
    r"(?i)\bOMFS\b",

    # Misspellings & Typographical Errors
    r"(?i)\bOral\s?and\s?Maxilofacial\s?Surgeon\b",
    r"(?i)\bOral\s?and\s?Maxillafacial\s?Surgeon\b",
    r"(?i)\bOral\s?and\s?Maxilofacil\s?Surgeon\b",
    r"(?i)\bOral\s?and\s?Maxilofascial\s?Surgeon\b",
    r"(?i)\bOral\s?and\s?Maxilofasial\s?Surgeon\b",
    r"(?i)\bOral\s?Maxillofacial\s?Surgeon\b",
    r"(?i)\bOral\s?Maxilofacial\s?Surgeon\b",
    r"(?i)\bOral\s?Maxilofacil\s?Surgeon\b",
    r"(?i)\bOral\s?Maxilofascial\s?Surgeon\b",
    r"(?i)\bOral\s?Maxilofasial\s?Surgeon\b",
    r"(?i)\bOral\s?&\s?Maxilofacial\s?Surgeon\b",

    # Case Variations
    r"(?i)\boral and maxillofacial surgeon\b",
    r"(?i)\bOral And Maxillofacial Surgeon\b",
    r"(?i)\bORAL AND MAXILLOFACIAL SURGEON\b",
    r"(?i)\bOrAl aNd MaXiLloFaCiaL SuRgEoN\b",

    # Spanish Variants
    r"(?i)\bCirujano\s?Oral\s?y\s?Maxilofacial\b",
    r"(?i)\bCirugía\s?Oral\s?y\s?Maxilofacial\b",
    r"(?i)\bEspecialista\s?en\s?Cirugía\s?Oral\s?y\s?Maxilofacial\b",
    r"(?i)\bCirujano\s?Oral\s?y\s?Facial\b",

    # Other Possible Variations (Including Doctor forms, Specialist forms)
    r"(?i)\bOral\s?and\s?Maxillofacial\s?Physician\b",
    r"(?i)\bOral\s?and\s?Maxillofacial\s?Specialist\b",
    r"(?i)\bOral\s?Surgeon\b",
    r"(?i)\bOral & Maxillofacial Surgery\b",
    r"(?i)\bHarmonizacao Orofacial\b",
    r"(?i)\bOmf Surgeon\b",
    r"(?i)\bOrofacial Harmonization\b",
    r"(?i)\bOral Surgeon & Medical Aesthetic Doctor\b",
    r"(?i)\bOral Surgery\b",
]

# Exact matches that should be updated
oral_maxillofacial_exact_matches = {
    "Oral and Maxillofacial Surgeon",
    "Oral & Maxillofacial Surgeon",
    "OMFS",
    "Oral and Maxilofacial Surgeon",
    "Oral and Maxillafacial Surgeon",
    "Oral and Maxilofacil Surgeon",
    "Oral and Maxilofascial Surgeon",
    "Oral and Maxilofasial Surgeon",
    "Oral Maxillofacial Surgeon",
    "Oral Maxilofacial Surgeon",
    "Oral Maxilofacil Surgeon",
    "Oral Maxilofascial Surgeon",
    "Oral Maxilofasial Surgeon",
    "Oral & Maxilofacial Surgeon",
    "Cirujano Oral y Maxilofacial",
    "Cirugía Oral y Maxilofacial",
    "Especialista en Cirugía Oral y Maxilofacial",
    "Cirujano Oral y Facial",
    "Oral and Maxillofacial Physician",
    "Oral and Maxillofacial Specialist",
    "Oral Surgeon",
    'Oral & Maxillofacial Surgery',
    'Orl',
    'Oral & Mixilo-Facial',
}

# # Define patterns (these should NOT be changed)
# oral_maxillofacial_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

oral_maxillofacial_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Oral and Maxillofacial Surgeon
mask_oral_maxillofacial = df['speciality'].str.contains('|'.join(oral_maxillofacial_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(oral_maxillofacial_exact_matches)

# mask_oral_maxillofacial_exclusions = df['speciality'].str.contains(oral_maxillofacial_exclusions, case=False, na=False, regex=True)
mask_oral_maxillofacial_exclusions = df['speciality'].isin(oral_maxillofacial_exclusions)

# Final mask: Select Oral and Maxillofacial Surgeon
mask_oral_maxillofacial_final = mask_oral_maxillofacial & ~mask_oral_maxillofacial_exclusions

# Store the original values that will be replaced
original_oral_maxillofacial_values = df.loc[mask_oral_maxillofacial_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_oral_maxillofacial_final, 'speciality'] = 'Oral and Maxillofacial Surgeon'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Oral and Maxillofacial Surgeon", 'green'))
print(df.loc[mask_oral_maxillofacial_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_oral_maxillofacial_values = df.loc[mask_oral_maxillofacial_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Oral and Maxillofacial Surgeon", "cyan"))
for original_oral_maxillofacial_value in original_oral_maxillofacial_values:
    print(f"✅ {original_oral_maxillofacial_value} → Oral and Maxillofacial Surgeon")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Oral and Maxillofacial Surgeon:", 'red'))
print(grouped_oral_maxillofacial_values)

# Print summary
matched_count_oral_maxillofacial = mask_oral_maxillofacial_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Oral and Maxillofacial Surgeon: "
        f"{matched_count_oral_maxillofacial}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Consultant related titles

consultant_variants = [
    r"(?i)\bSenior\s?Consultant\b",
    r"(?i)\bMedical\s?Consultant\b",
    r"(?i)\bBusiness\s?Consultant\b",
    r"(?i)\bCorporate\s?Consultant\b",
    r"(?i)\bProfessional\s?Consultant\b",
    r"(?i)\bSpecialist\s?Consultant\b",
    r"(?i)\bIndustry\s?Consultant\b",
    r"(?i)\bAesthetic ConsultantManager\b",
    r"(?i)\bCosmetic Business Consultancy\b",
    r"(?i)\bMedical Writing\b",
    r"(?i)\bConsultant Dermatology Oncology\b",
    r"(?i)\bCertified Uae Innovation Award Assessor\b",
    r"(?i)\bConsultant Otorhinolaryngology\b",
    r"(?i)\bHead Of Enterprise Architecture Office\b",
    r"(?i)\bRuralplanningField\b",
    r"(?i)\bMedical Scientific Consultant\b",
    r"(?i)\bConsultant Medical\b",
    r"(?i)\bStrategic Leadership Consulting & Account Services\b",
    r"(?i)\bBroker\b",
    r"(?i)\bPatient Consultant\b",
    r"(?i)\bPublic Health Specialist\b",
    r"(?i)\bMedical Information Specialist\b",
    r"(?i)\bMedical Writing\b",
    r"(?i)\bConsultant Specialist\b",
    r"(?i)\bCertified Uae Innovation Award Assessor\b",
    r"(?i)\bAesthetics Business Consultant\b",
    r"(?i)\bHead Of Enterprise Architecture Office\b",
    r"(?i)\bHealth Industry Consultant\b",
    r"(?i)\bHealthcare Information Services\b",
    r"(?i)\bAccount Specialist\b",
    r"(?i)\bMedical Scientific Consultant\b",
    r"(?i)\bMedical Consultant\b",
    r"(?i)\bEnvironmental Health Specialist\b",
    r"(?i)\bConsultora\b",
    r"(?i)\bSpecialist Financial Asviswr To Medics & Dentists\b",
    r"(?i)\bRuralplanningField\b",
    r"(?i)\bConsultant Medical\b",
    r"(?i)\bMedical DirectorInjectorHormone Specialist\b",
    r"(?i)\bStrategic Leadership Consulting & Account Services\b",
    r"(?i)\bBroker\b",
    r"(?i)\bPatient Consultant\b",
    r"(?i)\bSenior Consultant\b",
    r"(?i)\bBusiness Consultant\b",
    r"(?i)\bMedical Specialist\b",
    r"(?i)\bSr  Live Chat Specialist\b",
    r"(?i)\bAesthetic ConsultantManager\b",
    r"(?i)\bConsultant Medical Specialist\b",
    r"(?i)\bSpecialist Registrar\b",
    r"(?i)\bIndustry Consultant\b",
    r"(?i)\bLeading Specialist\b",
    r"(?i)\bAesthetic Medical Consultant\b",
    r"(?i)\bRegulatory & Npd Specialist\b",
    r"(?i)\bBd Specialist\b",
    r"(?i)\bRegulator Of Medical Devices\b",
    r"(?i)Claims Consultant",
]

# Exact matches that should be updated
consultant_exact_matches = {
    "Consultant",
    "Senior Consultant",
    "Medical Consultant",
    "Business Consultant",
    "Corporate Consultant",
    "Professional Consultant",
    "Specialist Consultant",
    "Industry Consultant",
    'Specialist',
    'Consulting',

    # Common misspellings for Consultant titles
    "Consulant",
    "Consultent",
    "Consultnt",
    "Consultat",
    "Conslutant",
    "Consulatnt",
    "Consutant",
    "Cosultant",

    # Case-related errors for Consultant
    "consultant",
    "CONSULTANT",
    "Consultant",
    "senior consultant",
    "Senior consultant",
    "medical consultant",
    "business consultant",
    "corporate consultant",

    # Variants of Consultant for different types in Spanish
    "Consultor",
    "Consultora",
    "Consultor Médico",
    "Consultor de Negocios",
    "Consultor Corporativo",
    "Consultor Profesional",
    "Consultor Especialista",

    # Other possible variations (Including related terms)
    "Adviser",
    "Advisor",
    "Senior Adviser",
    "Medical Adviser",
    "Corporate Adviser",
    "Professional Adviser",
    "Industry Adviser",
    "Specialist Adviser",
    
    # values from data sources
    'Specialist',
    'specialist',
    'Consultant Dermatology',
    'Healthcare Information Services',
    'Specialist',
    'Consultante',
    'Consaltant',
    'Aesthetic Consultant',
    'Cosmetic Consultant',
    'Aesthetic Retail Consultant',
    'C M E',
    'CLIFTONLARSONALLEN LLP',
    'Cosmetic Concierge',
    'Exosome Specialist BENEV Consultant',
    'Functional Medicine Consultant',
    'Aesthetic Technology Consultant',
    'General Vascular & Trauma Surgery Consultant Hayes Locums',
    'Claims Consultant - Physicians & Surgeons Mideast',
    'Client Developer - Pathology & Dermatology',
    'Physician Advocate',
    'Physician Human Resources Advocate',
    'Physician Informatics Senior Advocate',
    'Physician Liaison',
    'Physician Liaison Physician Outreach & Engagement',
    'Physician Liaison Soar',
    'Physician Network Liaison',
    'Senior Locums Consultant General Trauma & Vascular Surgery',
    'Senior Physician Liaison',
    'Sound Physicians Privileging Consultant',
    'Transplant Physician Liaison Senior',
    'Autonomous',
    'CAC',
}

# Define patterns (these should NOT be changed)
consultant_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident Physician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident'
}

# Create a mask for Consultant
mask_consultant = df['speciality'].str.contains('|'.join(consultant_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(consultant_exact_matches)
mask_consultant_exclusions = df['speciality'].isin(consultant_exclusions)

# Final mask: Select Consultant
mask_consultant_final = mask_consultant & ~mask_consultant_exclusions

# Store the original values that will be replaced
original_consultant_values = df.loc[mask_consultant_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_consultant_final, 'speciality'] = 'Consultant'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Consultant", 'green'))
print(df.loc[mask_consultant_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_consultant_values = df.loc[mask_consultant_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Consultant", "cyan"))
for original_consultant_value in original_consultant_values:
    print(f"✅ {original_consultant_value} → Consultant")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Consultant:", 'red'))
print(grouped_consultant_values)

# Print summary
matched_count_consultant = mask_consultant_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Consultant: "
        f"{matched_count_consultant}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for aesthetic_physician related titles
aesthetic_physician_variants = [
    r"(?i)\bAesthetic\s?Physician\b",
    r"(?i)\bAesthetic\s?Med\s?Physician\b",
    r"(?i)\bAesthetic\s?Practitioner\b",
    r"(?i)\bAesthetic\s?Medicine\s?Physician\b",
    r"(?i)\bAesthetic\s?MD\b",
    r"(?i)\bAesthetic\s?Physician\s?Specialist\b",
    r"(?i)\bAesthetic\s?Doctor\b",
    r"(?i)\bAesthetic\s?Physician\s?Expert\b",
    r"(?i)\bMédico\s?Estético\b",
    r"(?i)\bMédico\s?De\s?Estética\b",
    r"(?i)\bMédico\s?Especialista\s?En\s?Estética\b",
    r"(?i)\bEspecialista\s?En\s?Medicina\s?Estética\b",
    r"(?i)\bMédico\s?En\s?Medicina\s?Estética\b",
    r"(?i)\bAesthetics Medicine\b",
    r"(?i)\bAedthetic Doctor\b",
    r"(?i)\bAesthetic Doktor\b",
    r"(?i)\bAesthetic Injections\b",
    r"(?i)\bAesthetic InjectorOwner\b",
    r"(?i)\bAesthetic Medici E\b",
    r"(?i)\bAesthetic Medicibe\b",
    r"(?i)\bAesthetic MedicineMd\b",
    r"(?i)\bAesthetic Medicines\b",
    r"(?i)\bAesthetic Medicinr\b",
    r"(?i)\bAesthetic Medicinr\b",
    r"(?i)\bAesthetic Phicisian\b",
    r"(?i)\bAesthetic Phisician\b",
    r"(?i)\bAesthetic Physian\b",
    r"(?i)\bAesthetic Physichian\b",
    r"(?i)\bAesthetic Physicians\b",
    r"(?i)\bAesthetic Physiocan\b",
    r"(?i)\bAesthetic Practiocioner\b",
    r"(?i)\bAesthetic Practitionar\b",
    r"(?i)\bAesthetic Practitioners\b",
    r"(?i)\bAesthetic S\b",
    r"(?i)\bAesthetic Specialty\b",
    r"(?i)\bAesthetic Toxins\b",
    r"(?i)\bAesthetical Doctor\b",
    r"(?i)\bAesthetical Medecin\b",
    r"(?i)\bAesthetiv Medicine\b",
    r"(?i)\bAesthitic Physician\b",
    r"(?i)\bAesthteic Docto\b",
    r"(?i)\bAestehtics Physician & Co Found\b",
    r"(?i)\bAestethic Medicine\b",
    r"(?i)\bArathetic Physician\b",
    r"(?i)\bAsthetic Medicine\b",
    r"(?i)\bAsthetic Physician\b",
    r"(?i)\bAsthteics Medicine\b",
    r"(?i)\bMedica Estetica\b",
    r"(?i)\bMedica Esttica No Quirurgica\b",
    r"(?i)\bMedico Estetici\b",
    r"(?i)\bPhysician Aesthetic Medicine\b",
    r"(?i)\bMedical Arsthetics\b",
    r"(?i)\bMsc Aesthetic Medicine\b",
    r"(?i)\bAesthetic Medecine Spec\b",
    r"(?i)\bPhysician  Esthetic Medicine\b",
    r"(?i)\bEsthetic Medecine\b",
    r"(?i)\bAesthethic Medicine\b",
    r"(?i)\bMedicine Aesthetic\b",
    r"(?i)\bEsthetique Medecine\b",
    r"(?i)\bAesthics\b",
    r"(?i)\bAesthetist\b",
    r"(?i)\bMedicina Estetca\b",
    r"(?i)\bEstetik Doktor\b",
    r"(?i)\bEsthetic Medicine\b",
    r"(?i)\bMedical Aesthetic\b",
    r"(?i)\bMedicine Stetic\b",
    r"(?i)\bAesthetic Injectables\b",
    r"(?i)\bAsthetics\b",
    r"(?i)\bMedicin Estetica\b",
    r"(?i)\bEstetica Medica\b",
    r"(?i)\bMedicina Estetica\b",
    r"(?i)\bMedecin Esthetique\b",
    r"(?i)\bMedecine Esthetique\b",
    r"(?i)Harmonizacao Facial",
    r"(?i)\bAesthethic Specialist\b",
    r"(?i)\bSpecialist Of Aesthetic Medicine\b",
    r"(?i)\bAdvanced Facial Aesthetics\b",
    r"(?i)\bAestehtic Specialist\b",
    r"(?i)\bM D AAesthetic Medicine\b",
    r"(?i)\bAeshtetic Medicine Dr\b",
]

# Exact matches that should be updated
aesthetic_physician_exact_matches = {
    'Aesthetic Physician',
    'Aesthetic Medicine Physician',
    'Aesthetic Doctor',
    'Aesthetic MD',
    'Aesthetic Practitioner',
    'Aesthetic Medicine Doctor',
    'Aesthetic Physician Expert',
    'Aesthetic Medicine Specialist',
    'Aesthetic Physician Specialist',
    'Aesthetic Medicine Doctor',
    'Aesthetic Medical Specialist',
    'Aesthetic Medical Doctor',
    'Aesthetic Medicine Expert',
    'Aesthetic Physician Specialist',
    'Aesthetic Physician Expert',
    'Aesthetic Medicine Doctor',
    'Estetica',
    'estetica',
    'Esthetique',
    'esthetique',
    'Medical Aesthetics',
    'medical aesthetics',
    'Medico Estetico',

    # Spanish Titles:
    'Médico Estético',
    'Médico De Estética',
    'Médico Especialista En Estética',  # Spanish: Aesthetic Physician, Aesthetic Doctor
    'Especialista En Medicina Estética',
    'Médico En Medicina Estética',  # Spanish: Specialist in Aesthetic Medicine
    'Doctor Estético',
    'Doctor De Estética',
    'Especialista En Estética',  # Spanish: Aesthetic Doctor, Specialist
    'Médico Estético Clínico',
    'Médico Estético Especialista',  # Spanish: Clinical Aesthetic Physician, Specialist Aesthetic Physician

    # Misspelled Titles (Aesthetic Physician related):
    'Aesthetic Physcian',
    'Aesthetic Pysician',
    'Aestehtic Physician',
    'Aesthetic Phyisician',
    'Aesthetic Physcian',
    'Aesthetich Physician',
    'Aesthic Physician',
    'Esthetic Physician',
    'Aesthetic Phycian',
    'Aestetic Physician',
    'Aesthetic Phrysician',
    'Aesthetic Physican',
    'Aesthetic Phsycian',
    'Aesthetic Physicin',
    'Aesthetic Physicain',

    # Case Mistakes (Captures both upper and lower case versions):
    'Aesthetic physician',
    'aesthetic physician',
    'AESTHETIC PHYSICIAN',
    'AESTHETIC physician',
    'aesthetic Physician',
    'aEsthetic physician',
    'Aesthetic PhysIcian',
    'Aesthetic PhYsician',

    # Common Misspellings:
    'Aesthetic Physican',
    'Aestehtic Doctor',
    'Aesthetic Physicain',
    'Aesthetic Phycian',
    'Aesthetic Medicin Physician',
    'Aesthetic Doctor Medicine',
    'Aestehtic Medical Doctor',
    'Aesthetic Doctor Physican',
    'Aesthetic Medical Practicioner',
    'Aesthetic Medicin Practitioner',
    'Aestethic Physician',
    'Aesthetic Practicioner',

    # Case-related Errors
    'aesthetic Physician',
    'Aesthetic physician',
    'Aesthetic PHYSICIAN',
    'AESTHETIC Physician',
    'aEsthetic PHYSICIAN',
    'aesthetic Physician Expert',
    'aesthetic Physican Expert',
    'Aesthetic physiCian',
    
    # Spanish Variants for Aesthetic Physician:
    'Médico Estético',
    'Médico De Estética',
    'Médico Especialista En Estética',  # Aesthetic Physician
    'Especialista En Medicina Estética Antienvejecimiento',
    'Médico Estético Clínico',  # Clinical Aesthetic Physician
    'Médico Estético Especialista',
    'Doctor Estético',
    'Doctor De Estética',  # Aesthetic Doctor
    'Médico De Estética Avanzada',  # Advanced Aesthetic Physician
    'Médico Estético Experto',  # Expert Aesthetic Physician

    # Doctor Forms:
    'Aesthetic Doctor',
    'Doctor Aesthetic',
    'Doctor of Aesthetic Medicine',
    'Aesthetic Medicine Doctor',
    'Aesthetic Practitioner',

    # Specialist Forms:
    'Aesthetic Specialist',
    'Aesthetic Medicine Specialist',
    'Aesthetic Medicine Expert',
    'Specialist in Aesthetic Medicine',
    'Aesthetic Medicine Expert',
    'Expert Aesthetic Physician',
    'Aesthetic Specialist Physician',
    
    # values from data sources
    'Aesthetic Medicine',
    "Aestetic Medicine",
    "Aesthetic Medcine",
    "Aesthetic Medicne",
    "Aesthic Medicine",
    "Aestetic Medicne",
    "Aesthetic Medecine",
    "Aesthetic Mdicine",
    "Aestheic Medicine",
    "Aethestic Medicine",
    'Aesthetics',
    'Aesthetic',
    'Aesthetics Practitioner',
    'Aesthetics Medicine',
    'Aesthetic Injector',
    'Esthetic',
    'Aesthetics Doctor',
    'Esthetic Doctor',
    'Aesthetic Medine Doctor',
    'Aesthteic Doctor',
    'Facial Injector',
    'Medical DirectorAesthetic Doctor',
    'Medical Estetic Doctor',
    'Physicician Injector',
    'Euaesthetic Director',
    'Minimally Invasive Aesthetics',
    'Aesthetics Md',
    'Osteopath & Medical Aesthetics',
    'Advanced Aesthetics',
    'Aesthetics Medical',
    'Advanced Aesthetics Practitioner',
    'Medical Aesthetics & Bhrt',
    'Med Aesthetics',
    'Chief Injector',
    'Arztin Fur Asthetische Medizin',
    'Aeathetic Doctor',
    'Non Surgical Aesthetics',
    'Medicinal Aesthetics',
    'Evoluzzione',
    'Aestetic Physician Rehabilitation',
    'Osteopathe Esthetique',
    'Diploma Of Non-Surgical Medical Aesthetics',
    'Lifting Threads',
    'Medecin EsthetiqueGeneraliste',
    'Medical Esthetic',
    'Integrative Aesthetics',
    'Esthetic & Famille Doctor',
    'Aesthetic Medical',
    'Easthetic Medicine',
    'Medical Estetik',
    'Physician Injector',
    'Aesthetic Medical Practitioner',
    'Facial Rejuvenation',
    'Aesthetics Physician',
    'Medicio Estetico',
    'Aesthetic Master',
    'Aesthetic Care Specialist',
    'Advanced Aestetic Injector',
    'Advanced aesthetic injector',
    'Doctor - injector',
    'Doctor Asthetic Physcian',
    'Esthetic Injector',
    'Esthetic physician',
    'MEDICO ESTETICO',
    'Medico estetico',
    'CAE LE',
    'Aesthetics Provider',
    'Certified Laser Tech',
    'Certified Laser Tecnician',
    'Esthetique generale',
}

# Define patterns for  Aesthetic & Anti-Aging Physician & Anti Aging Physician & Resident & Professor (these should NOT be changed)
aesthetic_physician_exclusions = {
    'Nurse Aesthetic Practitioner',
    'Aesthetic & Anti-Aging Physician',
    'Aesthetic & AntiAging Physiican',
    'Aesthetic Anti-Aging Physican',
    'Aesthetic Anti Aging Physcian',
    'Aesthetic Anti Aging Pracitioner',
    'Aesthetic Anti-Aging Medical Doctor',
    'Aesthetic AntiAging Medical Dotor',
    'Aesthetic Anti Aging Speciallist',
    'Aesthetic Anti Aging Pracitioner',
    'Aesthetic Anti Aging Practicioner',
    'Aesthetic AntiAging Pracitioner',
    'Aesthetic Antiaging Medical Doctor',
    'Aesthetic AntiAging Surgeion',
    'Aesthetic Anti Aging Medcial Specalist',
    'Aesthetic Anti Aging Physican',
    'Aesthetic Anti-Aging Speciallist',
    'Aesthetic Anti Aging Healthcare Practicioner',
    'Aesthetic AntiAging Specilist',
    'Aesthetic Anti Aging Aesthetician',
    'Aesthetic AntiAging Surgeion',
    'Aesthetic Antiaging Doctor',
    'Aesthetic Antiaging Healthcare Specialist',
    'Aesthetic & Anti-Aging Practicioner',
    'Anti-aging Physician',
    'Anti Aging Physician',
    'anti aging physician',
    'anti-aging physician',
    'Antiaging Physician',
    'AntiAging Physician',
    'antiaging physician',
    'antiAging physician',
    'anti-ageing physician',
    'anti ageeing physician',
    'Anti-Aging Dr.',
    'Anti Aging Dr.',
    'anti-aging dr',
    'anti aging dr',
    'Anti-Aging Specialist',
    'Anti Aging Specialist',
    'anti aging specialist',
    'anti-aging specialist',
    'Anti-aging Practitioner',
    'Anti Aging Practitioner',
    'anti-aging practitioner',
    'anti aging practitioner',
    'Anti-aging Physician Clinic',
    'Anti Aging Physician Clinic',
    'anti-aging physician clinic',
    'anti aging physician clinic',
    'Anti-aging MD',
    'Anti Aging MD',
    'anti-aging md',
    'anti aging md',
    'Anti-Aging Medical Doctor',
    'Anti Aging Medical Doctor',
    'anti-aging medical doctor',
    'anti aging medical doctor',
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident Physician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Assistante Medecine Esthetique',
    'Medical Aesthetics Registered Nurse',
    'Aesthetic InjectorOwner',
    'Asistente Medico Estetico',
    'Prof  Esthetic Medicine Dentist',
    'Medical Aesthetic Manager',
    'Dentist Aesthetic Doctor',
    'Dermatologista E Medicina Estetica',
    'Oral Surgeon & Medical Aesthetic Doctor',
    'Gynecology Esthetic Medicine',
    'Dermatologist & Aesthetic Doctor',
    'Pharmacist-Aesthetic Practitioner',
    'Md Dermatology & Asthetics',
    'Oncologist & Medical Aesthetic',
    'Obgy & Asthetic Medicine',
    'Aesthetic Physician Assistant',
    'Medical Aesthetic Designer',
}

# Create a mask for Aesthetic Physician
mask_aesthetic_physician = df['speciality'].str.contains('|'.join(aesthetic_physician_variants), case=False, na=False, regex=True) | \
            df['speciality'].isin(aesthetic_physician_exact_matches)
mask_aesthetic_physician_exclusions = df['speciality'].isin(aesthetic_physician_exclusions)

# Final mask: Select Aesthetic Physician
mask_aesthetic_physician_final = mask_aesthetic_physician & ~mask_aesthetic_physician_exclusions

# Store the original values that will be replaced
original_aesthetic_physician_values = df.loc[mask_aesthetic_physician_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_aesthetic_physician_final, 'speciality'] = 'Aesthetic Physician'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Aesthetic Physician", 'green'))
print(df.loc[mask_aesthetic_physician_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_aesthetic_physician_values = df.loc[mask_aesthetic_physician_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Aesthetic Physician", "cyan"))
for original_aesthetic_physician_value in original_aesthetic_physician_values:
    print(f"✅ {original_aesthetic_physician_value} → Aesthetic Physician")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Aesthetic Physician:", 'red'))
print(grouped_aesthetic_physician_values)

# Print summary
matched_count_aesthetic_physician = mask_aesthetic_physician_final.sum()

# Print results
print(colored(f"\nTotal values matched and changed (Stage 1) to Aesthetic Physician: {matched_count_aesthetic_physician}", 'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for anatomist related titles
anatomist_variants = [
    r"(?i)\bAnatomist\b",
    r"(?i)\bAnatomy Specialist\b",
    r"(?i)\bAnatomy Expert\b",
    r"(?i)\bAnatomy Doctor\b",
    r"(?i)\bAnatomical Scientist\b",
    r"(?i)\bAnatomic Pathologist\b",
    r"(?i)\bAnatomy Researcher\b",
    r"(?i)\bAnatomy Lecturer\b",
    r"(?i)\bProfessor of Anatomy\b",
    r"(?i)\bAnatomy\b",
    r"(?i)\bAnatomiapatologica\b",
    r"(?i)\bAnatomiapatologica\b",
]

# Exact matches that should be updated
anatomist_exact_matches = {
    'Anatomist',
    'Anatomy Specialist',
    'Anatomy Expert',
    'Anatomy Doctor',
    'Anatomical Scientist',
    'Anatomic Pathologist',
    'Anatomy Researcher',
    'Anatomy Lecturer',
    'Anatomy Consultant',
    'Medical Anatomist',
    'Clinical Anatomist',
    'Human Anatomist',
    'Surgical Anatomist',
    'Pathological Anatomist',

    # Case-related errors
    'anatomist',
    'ANATOMIST',
    'anAtOmIsT',
    'AnAToMIST',
    'aNATOMIST',
    'ANATOMy Specialist',

    # Spanish-related exclusions
    'Anatomista',
    'Especialista en Anatomía',
    'Médico Anatomista',
    'Científico Anatómico',
    'Patólogo Anatómico',
    'Investigador en Anatomía',
    'Docente de Anatomía',
    'Profesor de Anatomía',
    'Anatomía Clínica',
    'Anatomista Médico',
    'Experto en Anatomía',

}

# Define patterns for  & Resident & Professor (these should NOT be changed)
anatomist_exclusions = {
    'Plastic Surgeon & Anatomist',
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident Physician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Anatomist
mask_anatomist = df['speciality'].str.contains('|'.join(anatomist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(anatomist_exact_matches)
mask_anatomist_exclusions = df['speciality'].isin(anatomist_exclusions)

# Final mask: Select Anatomist
mask_anatomist_final = mask_anatomist & ~mask_anatomist_exclusions

# Store the original values that will be replaced
original_anatomist_values = df.loc[mask_anatomist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_anatomist_final, 'speciality'] = 'Anatomist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Anatomist", 'green'))
print(df.loc[mask_anatomist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_anatomist_values = df.loc[mask_anatomist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Anatomist", "cyan"))
for original_anatomist_value in original_anatomist_values:
    print(f"✅ {original_anatomist_value} → Anatomist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Anatomist:", 'red'))
print(grouped_anatomist_values)

# Print summary
matched_count_anatomist = mask_anatomist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Anatomist: "
        f"{matched_count_anatomist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Psychiatrist related titles

psychiatrist_variants = [
    # Standard Titles & Variants
    r"(?i)\bPsychiatrist\b",
    r"(?i)\bPsychiatric Doctor\b",
    r"(?i)\bDoctor of Psychiatry\b",
    r"(?i)\bMD Psychiatry\b",
    r"(?i)\bMental Health Doctor\b",
    r"(?i)\bPsychiatry Specialist\b",
    r"(?i)\bPsychiatry\b",
    r"(?i)\bEating Disorders\b",

    # Misspellings & Typographical Errors
    r"(?i)\bPsychaitrist\b",
    r"(?i)\bPsychiatristt\b",
    r"(?i)\bPsychitrist\b",
    r"(?i)\bPsyciatrist\b",
    r"(?i)\bPsychyatrist\b",
    r"(?i)\bPsychaitric Doctor\b",
    r"(?i)\bPsychitric Doctor\b",
    r"(?i)\bPsycatrist\b",
    r"(?i)\bPsychatrist\b",
    r"(?i)\bPsichiatrist\b",

    # Case Variations
    r"(?i)\bPSYCHIATRIST\b",
    r"(?i)\bpsychiatrist\b",
    r"(?i)\bPsYcHiAtRiSt\b",

    # Spanish Variants
    r"(?i)\bPsiquiatra\b",
    r"(?i)\bDoctor en Psiquiatría\b",
    r"(?i)\bEspecialista en Psiquiatría\b",
    r"(?i)\bMédico Psiquiatra\b",
    r"(?i)\bMD Psiquiatría\b",

    # Hybrid Spanish-English Variants
    r"(?i)\bPsiquiatrist\b",
    r"(?i)\bPsychiatra\b",

    # Other Possible Variations (Doctor Forms, Specialist Forms)
    r"(?i)\bConsultant Psychiatrist\b",
    r"(?i)\bSenior Psychiatrist\b",
    r"(?i)\bLead Psychiatrist\b",
    r"(?i)\bForensic Psychiatrist\b",
    r"(?i)\bChild Psychiatrist\b",
    r"(?i)\bGeriatric Psychiatrist\b",
    r"(?i)\bNeuropsychiatrist\b",
]

# Exact matches that should be updated
psychiatrist_exact_matches = {
    "Psychiatrist",
    "Psychiatric Doctor",
    "Doctor of Psychiatry",
    "MD Psychiatry",
    "Mental Health Doctor",
    "Psychiatry Specialist",
    "Psychaitrist",
    "Psychiatristt",
    "Psychitrist",
    "Psyciatrist",
    "Psychyatrist",
    "Psychaitric Doctor",
    "Psychitric Doctor",
    "Psycatrist",
    "Psychatrist",
    "Psichiatrist",
    "Psiquiatra",
    "Doctor en Psiquiatría",
    "Especialista en Psiquiatría",
    "Médico Psiquiatra",
    "MD Psiquiatría",
    "Psiquiatrist",
    "Psychiatra",
    "Consultant Psychiatrist",
    "Senior Psychiatrist",
    "Lead Psychiatrist",
    "Forensic Psychiatrist",
    "Child Psychiatrist",
    "Geriatric Psychiatrist",
    "Neuropsychiatrist",
    'Psychiatrie Naturalmedicine',
}

# # Define patterns (these should NOT be changed)
# psychiatrist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

psychiatrist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Psychiatrist
mask_psychiatrist = df['speciality'].str.contains('|'.join(psychiatrist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(psychiatrist_exact_matches)

# mask_psychiatrist_exclusions = df['speciality'].str.contains(psychiatrist_exclusions, case=False, na=False, regex=True)
mask_psychiatrist_exclusions = df['speciality'].isin(psychiatrist_exclusions)

# Final mask: Select Psychiatrist
mask_psychiatrist_final = mask_psychiatrist & ~mask_psychiatrist_exclusions

# Store the original values that will be replaced
original_psychiatrist_values = df.loc[mask_psychiatrist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_psychiatrist_final, 'speciality'] = 'Psychiatrist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Psychiatrist", 'green'))
print(df.loc[mask_psychiatrist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_psychiatrist_values = df.loc[mask_psychiatrist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Psychiatrist", "cyan"))
for original_psychiatrist_value in original_psychiatrist_values:
    print(f"✅ {original_psychiatrist_value} → Psychiatrist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Psychiatrist:", 'red'))
print(grouped_psychiatrist_values)

# Print summary
matched_count_psychiatrist = mask_psychiatrist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Psychiatrist: "
        f"{matched_count_psychiatrist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Influencer related titles

influencer_variants = [
    r"(?i)\bInfluencer\b",  # Standard title

    # Common misspellings and case errors
    r"(?i)\bInfluancer\b",
    r"(?i)\bInflluencer\b",
    r"(?i)\bInfluenser\b",
    r"(?i)\bInfluncer\b",
    r"(?i)\bInfulencer\b",

    # Spanish variants
    r"(?i)\bInfluenciador\b",
    r"(?i)\bInfluenciadora\b",
    r"(?i)\bCreador\s?de\s?Contenido\b",
    r"(?i)\bCreadora\s?de\s?Contenido\b",
    r"(?i)\bFigura\s?Pública\b",
    r"(?i)\bLíder\s?de\s?Opinión\b",

    # Other possible variations
    r"(?i)\bContent\s?Creator\b",
    r"(?i)\bSocial\s?Media\s?Influencer\b",
    r"(?i)\bDigital\s?Influencer\b",
    r"(?i)\bBrand\s?Ambassador\b",
    r"(?i)\bOnline\s?Personality\b",
    r"(?i)\bKOL\b",
    r"(?i)\bThought\s?Leader\b",
    r"(?i)\bBlogger\b",
    r"(?i)\bOnline\b",
    r"(?i)\bOnline Work\b",
    r"(?i)\bTiktok Earning\b",
]

# Exact matches that should be updated
influencer_exact_matches = {
    "Influencer",
    "Influancer",
    "Inflluencer",
    "Influenser",
    "Influncer",
    "Infulencer",
    # Spanish variants
    "Influenciador",
    "Influenciadora",
    "Creador de Contenido",
    "Creadora de Contenido",
    "Figura Pública",
    "Líder de Opinión",
    # Other possible variations
    "Content Creator",
    "Social Media Influencer",
    "Digital Influencer",
    "Brand Ambassador",
    "Online Personality",
    "KOL",
    "Thought Leader",
    'Public Figure Aesthetic Sexologist',
    'Human Right ActivismHumanitarian Actor',
}

# Define patterns (these should NOT be changed)
influencer_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
    'Thought Leader Liaison Strategic Marketing Immunology Dermatology',
}

# Create a mask for Influencer
mask_influencer = df['speciality'].str.contains('|'.join(influencer_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(influencer_exact_matches)
mask_influencer_exclusions = df['speciality'].isin(influencer_exclusions)

# Final mask: Select Influencer
mask_influencer_final = mask_influencer & ~mask_influencer_exclusions

# Store the original values that will be replaced
original_influencer_values = df.loc[mask_influencer_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_influencer_final, 'speciality'] = 'Influencer'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Influencer", 'green'))
print(df.loc[mask_influencer_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_influencer_values = df.loc[mask_influencer_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Influencer", "cyan"))
for original_influencer_value in original_influencer_values:
    print(f"✅ {original_influencer_value} → Influencer")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Influencer:", 'red'))
print(grouped_influencer_values)

# Print summary
matched_count_influencer = mask_influencer_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Influencer: "
        f"{matched_count_influencer}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Laboratory Medicine related titles

laboratory_medicine_variants = [
    r"(?i)\bLaboratory\s?Medicine\b",
    r"(?i)\bLab\s?Medicine\b",

    # Common misspellings and case errors
    r"(?i)\bLabratory\s?Medicine\b",
    r"(?i)\bLabortory\s?Medicine\b",
    r"(?i)\bLaborotory\s?Medicine\b",
    r"(?i)\bLaboratry\s?Medicine\b",
    r"(?i)\bLab Medicine\b",
    r"(?i)\bLabortary\s?Medicine\b",

    # Spanish variants
    r"(?i)\bMedicina\s?de\s?Laboratorio\b",
    r"(?i)\bMédico\s?de\s?Laboratorio\b",
    r"(?i)\bEspecialista\s?en\s?Medicina\s?de\s?Laboratorio\b",
    r"(?i)\bLaboratorio\s?Clínico\b",

    # Other possible variations
    r"(?i)\bLaboratory\s?Medicine\s?Specialist\b",
    r"(?i)\bLaboratory\s?Medicine\s?Physician\b",
    r"(?i)\bLaboratory\s?Medicine\s?Doctor\b",
    r"(?i)\bClinical\s?Laboratory\s?Specialist\b",
    r"(?i)\bBoard\s?Certified\s?Laboratory\s?Medicine\s?Doctor\b",
    r"(?i)\bMedico Laboral\b",
    r"(?i)Laboral",
    r"(?i)\bMagister En Analisis Y Diagnostico De Laboratorio\b",
    r"(?i)\bLaboratory Medicine\b",
    r"(?i)\bLaboratory Specialist\b",
    r"(?i)\bMedical Laboratory Technician\b",
    r"(?i)\bHead Of Laboratory\b",
    r"(?i)\bMagister En Analisis Y Diagnostico De Laboratorio\b",
    r"(?i)\bManager- Laboratory Services\b",
    r"(?i)\bLaboratory Manager\b",
    r"(?i)\bLaboratory Scientist\b",
    r"(?i)\bMedico Laboral\b",
    r"(?i)\bMedical Laboratory ScientistClinical Laboratory Technologist\b",
    r"(?i)\bMedical Laboratory Scientists\b",
    r"(?i)\bPrincipal Investigator & Head Of Laboratory\b",
    r"(?i)\bConstruction Forman Three Year Expriance & Constrction Material Laboratory 8 Years Expriance\b",
    r"(?i)\bLaboratory Technician\b",
    r"(?i)\bHead Of Laboratory Department\b",
    r"(?i)\bMedical Laboratory\b",
]

# Exact matches that should be updated
laboratory_medicine_exact_matches = {
    "Laboratory Medicine",
    "Lab Medicine",
    # Misspellings
    "Labratory Medicine",
    "Labortory Medicine",
    "Laborotory Medicine",
    "Laboratry Medicine",
    "Labortary Medicine",
    # Spanish variants
    "Medicina de Laboratorio",
    "Médico de Laboratorio",
    "Especialista en Medicina de Laboratorio",
    "Laboratorio Clínico",
    # Other possible variations
    "Laboratory Medicine Specialist",
    "Laboratory Medicine Physician",
    "Laboratory Medicine Doctor",
    "Clinical Laboratory Specialist",
    "Board Certified Laboratory Medicine Doctor",
    'Laboratory',
    'laboratory',
    'Lab',
    'lab',
}

# Define patterns (these should NOT be changed)
laboratory_medicine_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Laboratory Medicine
mask_laboratory_medicine = df['speciality'].str.contains('|'.join(laboratory_medicine_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(laboratory_medicine_exact_matches)
mask_laboratory_medicine_exclusions = df['speciality'].isin(laboratory_medicine_exclusions)

# Final mask: Select Laboratory Medicine
mask_laboratory_medicine_final = mask_laboratory_medicine & ~mask_laboratory_medicine_exclusions

# Store the original values that will be replaced
original_laboratory_medicine_values = df.loc[mask_laboratory_medicine_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_laboratory_medicine_final, 'speciality'] = 'Laboratory Medicine'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Laboratory Medicine", 'green'))
print(df.loc[mask_laboratory_medicine_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_laboratory_medicine_values = df.loc[mask_laboratory_medicine_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Laboratory Medicine", "cyan"))
for original_laboratory_medicine_value in original_laboratory_medicine_values:
    print(f"✅ {original_laboratory_medicine_value} → Laboratory Medicine")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Laboratory Medicine:", 'red'))
print(grouped_laboratory_medicine_values)

# Print summary
matched_count_laboratory_medicine = mask_laboratory_medicine_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Laboratory Medicine: "
        f"{matched_count_laboratory_medicine}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Physiotherapist related titles

physiotherapist_variants = [
    # Standard Titles & Variants
    r"(?i)\bPhysiotherapist\b",
    r"(?i)\bPhysical Therapist\b",
    r"(?i)\bPhysiotherapy Specialist\b",
    r"(?i)\bPhysiotherapist Specialist\b",
    r"(?i)\bPhysiotherapist Practitioner\b",
    r"(?i)\bPhysical Therapy Specialist\b",
    r"(?i)\bPhysiapist\b",
    r"(?i)\bHealth Therapist\b",
    r"(?i)\bFisioterapia Dermatofuncional E Gestora De Clinica\b",
    r"(?i)\bPhysiology\b",

    # Misspellings & Typographical Errors
    r"(?i)\bPhysiotherpist\b",
    r"(?i)\bPhysiotherapis\b",
    r"(?i)\bPhysiotherapst\b",
    r"(?i)\bPhysiotheraprist\b",
    r"(?i)\bPhysioterapist\b",
    r"(?i)\bPhysiotherpist\b",

    # Case Variations
    r"(?i)\bphysiotherapist\b",
    r"(?i)\bPHYSIOTHERAPIST\b",
    r"(?i)\bPhYsIoThErApIsT\b",
    r"(?i)\bPhysiotherapist\b",

    # Spanish Variants
    r"(?i)\bFisioterapeuta\b",
    r"(?i)\bTerapeuta Físico\b",
    r"(?i)\bEspecialista en Fisioterapia\b",
    r"(?i)\bFisioterapeuta Especialista\b",
    r"(?i)\bFisioterapeuta Clínico\b",
    r"(?i)\bFisioterapeuta Profesional\b",

    # Other Possible Variations
    r"(?i)\bPhysical Rehabilitation Specialist\b",
    r"(?i)\bPhysical Therapy Professional\b",
    r"(?i)\bRehabilitation Therapist\b",
    r"(?i)\bPhysical Care Specialist\b",
]

# Exact matches that should be updated
physiotherapist_exact_matches = {
    "Physiotherapist",
    "Physical Therapist",
    "Physiotherapy Specialist",
    "Physiotherapist Specialist",
    "Physiotherapist Practitioner",
    "Physical Therapy Specialist",
    "Physiotherpist",
    "Physiotherapis",
    "Physiotherapst",
    "Physiotheraprist",
    "Physioterapist",
    "Fisioterapeuta",
    "Terapeuta Físico",
    "Especialista en Fisioterapia",
    "Fisioterapeuta Especialista",
    "Fisioterapeuta Clínico",
    "Fisioterapeuta Profesional",
    "Physical Rehabilitation Specialist",
    "Physical Therapy Professional",
    "Rehabilitation Therapist",
    "Physical Care Specialist",
    'Doctor Of Physical Therapy',
}

# # Define patterns (these should NOT be changed)
# physiotherapist_exclusions = r'\b(?:Plastic)|(?:Physician)\b'

physiotherapist_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident ooPhysician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident',
}

# Create a mask for Physiotherapist
mask_physiotherapist = df['speciality'].str.contains('|'.join(physiotherapist_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(physiotherapist_exact_matches)

# mask_physiotherapist_exclusions = df['speciality'].str.contains(physiotherapist_exclusions, case=False, na=False, regex=True)
mask_physiotherapist_exclusions = df['speciality'].isin(physiotherapist_exclusions)

# Final mask: Select Physiotherapist
mask_physiotherapist_final = mask_physiotherapist & ~mask_physiotherapist_exclusions

# Store the original values that will be replaced
original_physiotherapist_values = df.loc[mask_physiotherapist_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_physiotherapist_final, 'speciality'] = 'Physiotherapist'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Physiotherapist", 'green'))
print(df.loc[mask_physiotherapist_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_physiotherapist_values = df.loc[mask_physiotherapist_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Physiotherapist", "cyan"))
for original_physiotherapist_value in original_physiotherapist_values:
    print(f"✅ {original_physiotherapist_value} → Physiotherapist")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Physiotherapist:", 'red'))
print(grouped_physiotherapist_values)

# Print summary
matched_count_physiotherapist = mask_physiotherapist_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Physiotherapist: "
        f"{matched_count_physiotherapist}",
        'red'))


import pandas as pd
import re
import unicodedata
import sys
import os
from termcolor import colored

# Define regex patterns for Company Representative related titles

company_representative_variants = [
    r"(?i)\bCompany\s?Representative\b",
    r"(?i)\bBusiness\s?Representative\b",
    r"(?i)\bCorporate\s?Representative\b",
    r"(?i)\bCompany\s?Rep\b",
    r"(?i)\bCorporate\s?Rep\b",
    r"(?i)\bBusiness\s?Rep\b",
    r"(?i)\bFirm\s?Representative\b",
    r"(?i)\bCommercial\s?Representative\b",
    r"(?i)\bOfficial\s?Representative\b",
    r"(?i)\bMedical Representative\b",
    r"(?i)\bRepresentative\b",
    r"(?i)\bHotelRestaurant Equipment\b",
    r"(?i)\bPhysician Liason\b",
    r"(?i)\bCustomer Service Rep\b",
    r"(?i)\bDmos Responsible\b",
    r"(?i)\bRep Sr Plastic Surgery Us Plastice Surgery\b",
    r"(?i)\bIncorporation Specialist\b",
    r"(?i)\bRep Plastic Surgery Us Plastic Surgery\b",
    r"(?i)\bRep Plastic Surgery Us Plastice Surgery\b",
    r"(?i)\bBrand Advocate\b",
]

# Exact matches that should be updated
company_representative_exact_matches = {
    "Company Representative",
    "Corporate Representative",
    "Business Representative",
    "Company Rep",
    "Corporate Rep",
    "Business Rep",
    "Firm Representative",
    "Commercial Representative",
    "Official Representative",

    # Common misspellings for Company Representative titles
    "Compny Representative",
    "Company Reprsentative",
    "Comapny Representative",
    "Company Reepresentative",
    "Company Represntative",
    "Coprporate Representative",
    "Busines Representative",
    "Company Represenative",

    # Case-related errors for Company Representative
    "company representative",
    "COMPANY REPRESENTATIVE",
    "Company representative",
    "corporate representative",
    "Corporate representative",
    "business representative",
    "Business representative",

    # Variants of Company Representative for different types in Spanish
    "Representante de Empresa",
    "Representante Corporativo",
    "Representante de Negocios",
    "Rep de Empresa",
    "Rep Corporativo",
    "Representante Comercial",
    "Representante Oficial",

    # Other possible variations (Including related terms)
    "Company Delegate",
    "Corporate Delegate",
    "Business Delegate",
    "Enterprise Representative",
    "Industry Representative",
    'Aesthetic Consultant Aesthetic Rep',
    'Customer Service',
    'Demonstrator',
}

# Define patterns (these should NOT be changed)
company_representative_exclusions = {
    'Resident',
    'resident',
    'student',
    'Trainee',
    'Resident Doctor',
    'Resident Physician',
    'Intern',
    'intern',
    'Medical Intern',
    'Fellow',
    'fellow',
    'Clinical Fellow',
    'Medical Student',
    'Clinical Trainee',
    'Trainee Doctor',
    'Trainee Physician',
    'Junior Doctor',
    'Postgraduate Trainee',
    'Aesthetic Fellow',
    'Aesthetic Trainee',
    'Aesthetic Medicine Fellow',
    'Aesthetic Resident'
}

# Create a mask for Company Representative
mask_company_representative = df['speciality'].str.contains('|'.join(company_representative_variants), case = False,
                                                          na = False, regex = True) | \
                            df['speciality'].isin(company_representative_exact_matches)
mask_company_representative_exclusions = df['speciality'].isin(company_representative_exclusions)

# Final mask: Select Company Representative
mask_company_representative_final = mask_company_representative & ~mask_company_representative_exclusions

# Store the original values that will be replaced
original_company_representative_values = df.loc[mask_company_representative_final, 'speciality'].unique()

# Update the speciality column based on exact matches
df.loc[mask_company_representative_final, 'speciality'] = 'Company Representative'

# Check AFTER updating
print(colored("\nUnique values AFTER updating: Company Representative", 'green'))
print(df.loc[mask_company_representative_final, 'speciality'].unique())

# GroupBy to count how many records were replaced by the new value
grouped_company_representative_values = df.loc[mask_company_representative_final, 'speciality'].value_counts()

# Print the exact replacements
print(colored("\nReplaced Values: Company Representative", "cyan"))
for original_company_representative_value in original_company_representative_values:
    print(f"✅ {original_company_representative_value} → Company Representative")

# GroupBy after replacement (to show the new value)
print(colored("\nGroupBy counts AFTER replacing with Company Representative:", 'red'))
print(grouped_company_representative_values)

# Print summary
matched_count_company_representative = mask_company_representative_final.sum()

# Print results
print(
    colored(
        f"\nTotal values matched and changed (Stage 1) to Company Representative: "
        f"{matched_count_company_representative}",
        'red'))